###########################################################################
#
#!make
#
#!Makefile Name: MOD_PR35.mk
#
#!Description: Makefile for compiling the Cloud Mask production
#              software (MOD_PR35).
#
#!Variables:
#
#       Internal
#        Macros           Definition
#       ~~~~~~~~          ~~~~~~~~~~
#       ADD_CFLAGS        Process specific C compiler options
#       ADD_F77FLAGS      Process specific FORTRAN 77 compiler options
#       ADD_F90FLAGS      Process specific FORTRAN 90 compiler options
#       HDF5OPT_LIB       Path name of HDF5 dynamically shared library
#       INC               Accumulated include file search path
#       INC_FILES_SCIENCE Process specific include files
#       INC_FILE_SHARED   Atmosphere shared include files
#       LIB               Accumulated library search path
#       OBJ               Accumulated set of object files
#       PATH_SRC_SDST     Directory path to SDST L2 atmosphere shared source
#       PATH_SRC_UW       Directory path to UW-Madison shared source
#       TARGET            Executable file name
#
#!Env Variables
#
#         System
#       Environment
#        Variables    Definition
#       ~~~~~~~~~~~   ~~~~~~~~~~
#       API_INC       Directory path to M-API include files
#       API_LIB       Directory path to M-API library
#       BRAND         Compiler brand. Current valids are "sgi64/sgi32/linux".
#                     "linux" denotes PGI compilers for FORTRAN code and GNU
#                     compilers for C.
#       CC            C compiler definition
#       CFLAGS        C compiler options
#       F77           FORTRAN 77 compiler definition
#       F77FLAGS      Common MODIS FORTRAN 77 compiler options
#       F90           FORTRAN 90 compiler definition
#       F90FLAGS      Common MODIS FORTRAN 90 compiler options
#       HDFEOS_INC    Directory path to HDFEOS include files
#       HDFEOS_LIB    Directory path to HDFEOS library
#       HDFINC        Directory path to HDF include files
#       HDFLIB        Directory path to HDF library
#       HDF5LIB       Directory path to HDF5 libraries
#       PGSINC        Directory path to SDPTK include files
#       PGSLIB        Directory path to SDPTK library
#
#        User
#       Environment
#        Variables    Definition
#       ~~~~~~~~~~~   ~~~~~~~~~~
#       MODIS_STORE   Home directory of MODIS shared source code
#
#!Team-Unique Header:
#       This software was developed by MODIS Science Data Support Team
#       for the National Aeronautics and Space Administration,
#       Goddard Space Flight Center, under contract NAS5-32373.
#
#!Revision History:
#$Id: MOD_PR35.mk,v 1.1 2006/02/07 22:45:31 gumley Exp $
#
#
#!Note:
#       1) must follow MAPI, SDP TK, HDF, and other header/libs order
#       2) HDFLIB must be explicit and in order of -lmfhdf, -ldf, -ljpeg, -lz.
#       3) system environments, such as API_INC, PGSINC, HDFINC, PGSLIB,
#          API_LIB etc. should be defined before executing this makefile.
#
#!END
###########################################################################

PATH_SRC_SDST = $(MODIS_STORE)/shared_src/atmos_src/src_L2
PATH_SRC_UW   = $(MODIS_STORE)/shared_src/atmos_src/src_UW

# Libraries 
# Define library search path; it includes libhdf5.so for SDPTK 5.2.8.3 and above.
# Note the use of make substitution operator: $(variable:pattern=replacement) 
# HDF5OPT_LIB = /$(HDF5LIB)/libhdf5.so
#
# Addendum:  MOD_PR35 is linked with the HDF5 static libraries instead of 
# dynamic libraries as previously used.  This ensures no conflicting usage of
# the HDF5 shared libraries when switching toolkit environments (64_f90 and 
# 64_f77) among the processes of PGE03.
#
# 2005-01-18: Reference to HDF5LIB changed to format below in order to compile
# under PGFTN/x86 Linux/x86 5.2-4 F77.  However, this points to the shared dynamic
# library at SDST.  It should point to the static library at the GDAAC.
#
LIB = -L$(API_LIB) -lmapi \
      -L$(PGSLIB) -lPGSTK -lm \
      -L$(HDFEOS_LIB) -lhdfeos -lGctp \
      -L$(HDF5LIB) -lhdf5 \
      -L$(HDFLIB) -lmfhdf -ldf -ljpeg -lz


# Objects
OBJ = \
       Antarctic_day.o                 CCSDS_FullTimeFormat_A.o \
       CONCATENATE.o                   Day_snow.o \
       Delete_CommonTempFiles_Atmos_V2.1.o  Delete_PCF_TempFile.o \
       Gen_Modis_FileName.o            Get_Core_Metadata.o \
       Get_Global_Metadata.o           Get_Swath_Metadata.o \
       Get_date_time.o                 LandDay.o \
       LandDay_coast.o                 LandDay_desert.o \
       LandDay_desert_c.o              LandNite.o \
       MODIS_IO_GEN_CLOSE.o            MODIS_IO_GEN_OPEN.o \
       MODIS_SMF_SETDYNAMICMSG_V2.1.o  MOD_PR35.o \
       Met_Common_Atmos.o              Nite_snow.o \
       Parse_ECS_DateTime.o            PolarDay_coast.o \
       PolarDay_desert.o               PolarDay_desert_c.o \
       PolarDay_land.o                 PolarDay_ocean.o \
       PolarDay_snow.o                 PolarNite_land.o \
       PolarNite_ocean.o               PolarNite_snow.o \
       Prepare_ECS_Metadata.o          Read_GEO_V2.o \
       Read_L1B_V2.2.o                 STRING_LOC.o \
       Set_ArchiveMetadata_V2.1.o \
       Set_CoreMetadata_V2.1.o         Set_Runtime_Meta.o \
       Write_ECSMetadata_nonHDF.o \
       blint_met.o                     bl_int.o \
       bright_m.o                      brite_m.o \
       check_bits.o                    check_qa_bits.o \
       check_reg_uniformity.o          chk_coast.o \
       chk_ele_edge.o                  chk_input.o \
       chk_input_L2.o                  chk_land.o \
       chk_land_nite.o                 chk_lin_edge.o \
       chk_shallow_water.o             chk_spatial_var.o \
       chk_sunglint.o                  clear_bit.o \
       compare_times.o \
       concatenate_2.o                 conf_test.o \
       conf_test_2val.o                copy_info.o \
       create_250m_cm.o                create_hdf.o \
       date_to_ccsds.o                 ezlh_convert.o \
       file_close.o                    file_open.o \
       fill_bit_line.o                 get_250m_data.o \
       get_L1b.o                       get_anc_data.o \
       get_ancillary_cld.o             get_angles.o \
       get_geo_copy.o \
       get_grid_index.o                get_nl_thresholds.o \
       get_platform_name.o             get_pn_thresholds.o \
       get_pxldat.o                    get_regdif.o \
       get_regstd.o                    get_rp.o \
       get_sg_thresholds.o             get_spec_info.o \
       get_stats.o                     getcoord.o \
       init_input.o                    init_meta.o \
       init_var.o                      isort.o \
       land_day.o                      land_day_250m.o \
       land_nite.o                     message_1.o \
       mod35_out.o                     modis_bright.o \
       modis_grib_driver_cld.o         modis_grib_read.o \
       noncld_obs_chk.o                ocean_day.o \
       ocean_day_250m.o                ocean_nite.o \
       openr_temp.o                    param_get_value.o \
       param_read_file.o               param_real.o \
       param_string.o                  polar_day.o \
       polar_nite.o                    ppv.o \
       proc_path.o                     pxinit.o \
       read_goode.o \
       read_nise_mod35.o \
       read_reynsst.o                  reorder_array.o \
       set_bit.o                       set_confdnc.o \
       set_qa_bit.o                    set_quality_A.o \
       set_unused_bits.o               setup_create_hdf.o \
       shadows.o                       snow_mask.o \
       spatial_var.o                   stats_out.o \
       store_cm_scan.o                 store_context.o \
       store_meta.o                    strcompress.o \
       strlen.o                        strlower.o \
       strpos.o                        svpwat.o \
       thin_ci_chk_ir.o                thresholds_read.o \
       trispc.o \
       tview.o                         chk_spatial2.o \
       water_day.o                     water_nite.o
       

# Include file search path
INC = -I$(API_INC) \
      -I$(HDFINC) \
      -I$(PGSINC) \
      -I$(HDFEOS_INC) \
      -I$(PATH_SRC_UW) \
      -I$(PATH_SRC_SDST)

# Include files developed by ST
INC_FILES_SCIENCE = \
      Antarctic_day_thr.inc \
      Day_snow_thr.inc \
      LandDay_coast_thr.inc \
      LandDay_desert_c_thr.inc \
      LandDay_desert_thr.inc \
      LandDay_thr.inc \
      LandNite_thr.inc \
      Nite_snow_thr.inc \
      PolarDay_coast_thr.inc \
      PolarDay_desert_c_thr.inc \
      PolarDay_desert_thr.inc \
      PolarDay_land_thr.inc \
      PolarDay_ocean_thr.inc \
      PolarDay_snow_thr.inc \
      PolarNite_land_thr.inc \
      PolarNite_ocean_thr.inc \
      PolarNite_snow_thr.inc \
      global.inc \
      land_restoral.inc \
      mod35.inc \
      mod35_meta.inc \
      noncld_obs_chk.inc \
      ocean_day_thr.inc \
      ocean_nite_thr.inc \
      shadows_thr.inc \
      snglntr_thr.inc \
      snow_mask.inc \
      spatial_var_thr.inc \
      swc_ndvi.inc \
      thresholds_ver.inc

# Include files from MODIS shared source
INC_FILES_SHARED  = $(PATH_SRC_SDST)/Atmos_ECSMET.inc \
                    $(PATH_SRC_SDST)/Atmos_AncData.inc \
                    $(PATH_SRC_UW)/L1B_Reader_V2.2.inc \
                    $(PATH_SRC_SDST)/atmos_hdf_eos.inc \
                    $(PATH_SRC_UW)/debug.inc \
                    $(PATH_SRC_UW)/modis_grib_read.h \
                    $(PATH_SRC_UW)/platform_name.inc

# Compiler options are set based on IRIX/LINUX environment. On Linux,
# FORTRAN codes are compiled using LINUX PGI compilers; C codes use the
# GNU compilers 
target :
	case "$(BRAND)" in \
         linux ) \
           $(MAKE) $(TARGET) -f MOD_PR35.mk \
                   ADD_CFLAGS="   -O2 -c -D_POSIX_SOURCE -funsigned-char" \
                   ADD_F77FLAGS=" -O2 -c -Mstandard" \
                   ADD_F90FLAGS=" -O2 -c -Mstandard" \
           ;; \
         * ) \
           $(MAKE) $(TARGET) -f MOD_PR35.mk \
                   ADD_CFLAGS="   -O2 -c -D_POSIX_SOURCE" \
                   ADD_F77FLAGS=" -O2 -c -u -bytereclen -col120 -woff 2271,2272,2274" \
                   ADD_F90FLAGS=" -O2 -c -u -bytereclen -col120 -woff 2271,2272,2274" \
           ;; \
       esac 

#---------------------------------------------------------------------------
#                  UW Development Environment
#
# Define development compiler options (this is the default mode)
# NOTE: THESE COMPILER FLAGS WERE CAREFULLY BY CHOSEN BY UW TO ASSIST IN
# DEVELOPMENT AND TESTING. UW IS NOT RESPONSIBLE FOR ANY ERRORS
# INTRODUCED IN THE CODE IF THESE FLAGS ARE DISABLED OR MODIFIED.
#CC=cc
#CFLAGS=-c -n32 -fullwarn -xansi -D_POSIX_SOURCE
#ADD_CFLAGS=-g -trapuv -lfpe -C
#
#F77=f77
#F77FLAGS=-c -n32 -fullwarn -u -bytereclen -extend_source -woff 2271,2272,2274
#ADD_F77FLAGS=-g -trapuv -lfpe -check_bounds -C
#
#F90=f90
#F90FLAGS=-c -n32 -fullwarn -u -bytereclen -extend_source -woff 2271,2272,2274
#ADD_F90FLAGS=-g -trapuv -lfpe -check_bounds -C
#
# Define optimized compiler options
# (To optimize the code uncomment these lines only: do nothing else!)
# NOTE: UW HAS TESTED THIS CODE ON SGI SYSTEMS USING '-O2' OPTIMZATION ONLY.
# UW IS NOT RESPONSIBLE FOR RUN-TIME ERRORS WHICH OCCUR AT ANY HIGHER
# LEVEL OF OPTIMIZATION.
# ADD_CFLAGS=-O2
# ADD_F77FLAGS=-O2
# ADD_F90FLAGS=-O2
#
# Libraries for development/debug (Note addition of floating point library
# at end of list)
#LIB = -L$(API_LIB) -lmapi\
#      -L$(PGSLIB) -lPGSTK -lm\
#      -L$(HDFEOS_LIB) -lhdfeos -lGctp\
#      -L$(HDFLIB) -lmfhdf -ldf -lz\
#      -lfpe
#---------------------------------------------------------------------------
                      

# Define internal macros
TARGET = MOD_PR35.exe

# Make executable
$(TARGET): $(OBJ)
	$(F90) $(OBJ) $(LIB) -o $@

#---------------------------------------------------------
# Build objects derived from mod35 science code
#---------------------------------------------------------

Antarctic_day.o: Antarctic_day.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) Antarctic_day.f

Day_snow.o: Day_snow.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) Day_snow.f

Get_Swath_Metadata.o: Get_Swath_Metadata.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) Get_Swath_Metadata.f

LandDay.o: LandDay.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) LandDay.f

LandDay_coast.o: LandDay_coast.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) LandDay_coast.f

LandDay_desert.o: LandDay_desert.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) LandDay_desert.f

LandDay_desert_c.o: LandDay_desert_c.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) LandDay_desert_c.f

LandNite.o: LandNite.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) LandNite.f

MOD_PR35.o: MOD_PR35.f $(INC_FILES_SCIENCE) $(INC_FILES_SHARED)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) MOD_PR35.f

Nite_snow.o: Nite_snow.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) Nite_snow.f

PolarDay_coast.o: PolarDay_coast.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarDay_coast.f

PolarDay_desert.o: PolarDay_desert.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarDay_desert.f

PolarDay_desert_c.o: PolarDay_desert_c.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarDay_desert_c.f

PolarDay_land.o: PolarDay_land.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarDay_land.f

PolarDay_ocean.o: PolarDay_ocean.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarDay_ocean.f

PolarDay_snow.o: PolarDay_snow.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarDay_snow.f

PolarNite_land.o: PolarNite_land.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarNite_land.f

PolarNite_ocean.o: PolarNite_ocean.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarNite_ocean.f

PolarNite_snow.o: PolarNite_snow.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) PolarNite_snow.f

Prepare_ECS_Metadata.o: Prepare_ECS_Metadata.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) Prepare_ECS_Metadata.f

Set_Runtime_Meta.o: Set_Runtime_Meta.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) Set_Runtime_Meta.f

check_bits.o: check_bits.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) check_bits.f

check_qa_bits.o: check_qa_bits.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) check_qa_bits.f

check_reg_uniformity.o: check_reg_uniformity.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) check_reg_uniformity.f

chk_coast.o: chk_coast.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_coast.f

chk_ele_edge.o: chk_ele_edge.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_ele_edge.f

chk_input.o: chk_input.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_input.f

chk_land.o: chk_land.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_land.f

chk_land_nite.o: chk_land_nite.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_land_nite.f

chk_lin_edge.o: chk_lin_edge.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_lin_edge.f

chk_shallow_water.o: chk_shallow_water.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_shallow_water.f

chk_spatial_var.o: chk_spatial_var.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_spatial_var.f

chk_spatial2.o: chk_spatial2.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_spatial2.f

chk_sunglint.o: chk_sunglint.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) chk_sunglint.f

clear_bit.o: clear_bit.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) clear_bit.f

concatenate_2.o: concatenate_2.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) concatenate_2.f

conf_test.o: conf_test.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) conf_test.f

conf_test_2val.o: conf_test_2val.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) conf_test_2val.f

create_250m_cm.o: create_250m_cm.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) create_250m_cm.f

file_close.o: file_close.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) file_close.f

file_open.o: file_open.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) file_open.f

fill_bit_line.o: fill_bit_line.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) fill_bit_line.f

get_250m_data.o: get_250m_data.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_250m_data.f

get_L1b.o: get_L1b.f $(INC_FILES_SCIENCE) $(INC_FILES_SHARED)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_L1b.f

get_anc_data.o: get_anc_data.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_anc_data.f

get_angles.o: get_angles.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_angles.f

get_geo_copy.o: get_geo_copy.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_geo_copy.f

get_nl_thresholds.o: get_nl_thresholds.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_nl_thresholds.f

get_pn_thresholds.o: get_pn_thresholds.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_pn_thresholds.f

get_pxldat.o: get_pxldat.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_pxldat.f

get_regdif.o: get_regdif.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_regdif.f

get_regstd.o: get_regstd.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_regstd.f

get_rp.o: get_rp.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_rp.f

get_sg_thresholds.o: get_sg_thresholds.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_sg_thresholds.f

get_stats.o: get_stats.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) get_stats.f

init_input.o: init_input.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) init_input.f

init_meta.o: init_meta.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) init_meta.f

init_var.o: init_var.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) init_var.f

land_day.o: land_day.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) land_day.f

land_day_250m.o: land_day_250m.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) land_day_250m.f

land_nite.o: land_nite.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) land_nite.f

mod35_out.o: mod35_out.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) mod35_out.f

noncld_obs_chk.o: noncld_obs_chk.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) noncld_obs_chk.f

ocean_day.o: ocean_day.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) ocean_day.f

ocean_day_250m.o: ocean_day_250m.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) ocean_day_250m.f

ocean_nite.o: ocean_nite.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) ocean_nite.f

param_get_value.o: param_get_value.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) param_get_value.f

param_read_file.o: param_read_file.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) param_read_file.f

param_real.o: param_real.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) param_real.f

param_string.o: param_string.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) param_string.f

polar_day.o: polar_day.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) polar_day.f

polar_nite.o: polar_nite.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) polar_nite.f

proc_path.o: proc_path.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) proc_path.f

pxinit.o: pxinit.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) pxinit.f

read_nise_mod35.o: read_nise_mod35.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) read_nise_mod35.f

reorder_array.o: reorder_array.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) reorder_array.f

set_bit.o: set_bit.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) set_bit.f

set_confdnc.o: set_confdnc.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) set_confdnc.f

set_quality_A.o: set_quality_A.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) set_quality_A.f

set_unused_bits.o: set_unused_bits.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) set_unused_bits.f

shadows.o: shadows.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) shadows.f

snow_mask.o: snow_mask.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) snow_mask.f

spatial_var.o: spatial_var.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) spatial_var.f

stats_out.o: stats_out.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) stats_out.f

store_cm_scan.o: store_cm_scan.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) store_cm_scan.f

store_context.o: store_context.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) store_context.f

store_meta.o: store_meta.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) store_meta.f

thin_ci_chk_ir.o: thin_ci_chk_ir.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) thin_ci_chk_ir.f

thresholds_read.o: thresholds_read.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) thresholds_read.f

trispc.o: trispc.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) trispc.f

tview.o: tview.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) tview.f

water_day.o: water_day.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) water_day.f

water_nite.o: water_nite.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) water_nite.f

#----------------------------------------------------------------------------------
# Build process specific object modules from UW-Madison shared source library files
#----------------------------------------------------------------------------------

Get_Core_Metadata.o: $(PATH_SRC_UW)/Get_Core_Metadata.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/Get_Core_Metadata.f

Get_Global_Metadata.o: $(PATH_SRC_UW)/Get_Global_Metadata.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/Get_Global_Metadata.f

Read_GEO_V2.o: $(PATH_SRC_UW)/Read_GEO_V2.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/Read_GEO_V2.f

Read_L1B_V2.2.o: $(PATH_SRC_UW)/Read_L1B_V2.2.f $(INC_FILES_SHARED)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/Read_L1B_V2.2.f

bl_int.o: $(PATH_SRC_UW)/bl_int.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/bl_int.f

blint_met.o: $(PATH_SRC_UW)/blint_met.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/blint_met.f

bright_m.o: $(PATH_SRC_UW)/bright_m.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/bright_m.f

brite_m.o: $(PATH_SRC_UW)/brite_m.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/brite_m.f

compare_times.o: $(PATH_SRC_UW)/compare_times.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/compare_times.f

copy_info.o: $(PATH_SRC_UW)/copy_info.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/copy_info.f

create_hdf.o: $(PATH_SRC_UW)/create_hdf.f $(PATH_SRC_SDST)/atmos_hdf_eos.inc
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/create_hdf.f

date_to_ccsds.o: $(PATH_SRC_UW)/date_to_ccsds.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/date_to_ccsds.f

ezlh_convert.o: $(PATH_SRC_UW)/ezlh_convert.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/ezlh_convert.f

getcoord.o: $(PATH_SRC_UW)/getcoord.c
	$(CC) $(CFLAGS) $(ADD_CFLAGS) $(INC) $(PATH_SRC_UW)/getcoord.c

get_ancillary_cld.o: $(PATH_SRC_UW)/get_ancillary_cld.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/get_ancillary_cld.f

get_grid_index.o: $(PATH_SRC_UW)/get_grid_index.f $(INC_FILES_SCIENCE)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/get_grid_index.f

get_platform_name.o: $(PATH_SRC_UW)/get_platform_name.f $(INC_FILES_SHARED)
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/get_platform_name.f

get_spec_info.o: $(PATH_SRC_UW)/get_spec_info.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/get_spec_info.f

isort.o: $(PATH_SRC_UW)/isort.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/isort.f

modis_bright.o: $(PATH_SRC_UW)/modis_bright.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/modis_bright.f

modis_grib_driver_cld.o: $(PATH_SRC_UW)/modis_grib_driver_cld.c $(PATH_SRC_UW)/modis_grib_read.h
	$(CC) $(CFLAGS) $(ADD_CFLAGS) $(INC) $(PATH_SRC_UW)/modis_grib_driver_cld.c

modis_grib_read.o: $(PATH_SRC_UW)/modis_grib_read.c $(PATH_SRC_UW)/modis_grib_read.h
	$(CC) $(CFLAGS) $(ADD_CFLAGS) $(INC) $(PATH_SRC_UW)/modis_grib_read.c

openr_temp.o: $(PATH_SRC_UW)/openr_temp.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/openr_temp.f

ppv.o: $(PATH_SRC_UW)/ppv.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/ppv.f

read_goode.o: $(PATH_SRC_UW)/read_goode.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/read_goode.f

set_qa_bit.o: $(PATH_SRC_UW)/set_qa_bit.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/set_qa_bit.f

setup_create_hdf.o: $(PATH_SRC_UW)/setup_create_hdf.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/setup_create_hdf.f

strcompress.o: $(PATH_SRC_UW)/strcompress.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/strcompress.f

strlower.o: $(PATH_SRC_UW)/strlower.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/strlower.f

strpos.o: $(PATH_SRC_UW)/strpos.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/strpos.f

svpwat.o: $(PATH_SRC_UW)/svpwat.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_UW)/svpwat.f

#-----------------------------------------------------------------------------
# Build process specific object modules from SDST shared source library files
#-----------------------------------------------------------------------------

CCSDS_FullTimeFormat_A.o: $(PATH_SRC_SDST)/CCSDS_FullTimeFormat_A.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/CCSDS_FullTimeFormat_A.f

CONCATENATE.o: $(PATH_SRC_SDST)/CONCATENATE.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/CONCATENATE.f

Delete_CommonTempFiles_Atmos_V2.1.o: $(PATH_SRC_SDST)/Delete_CommonTempFiles_Atmos_V2.1.f $(PATH_SRC_SDST)/Atmos_AncData.inc
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Delete_CommonTempFiles_Atmos_V2.1.f

Delete_PCF_TempFile.o: $(PATH_SRC_SDST)/Delete_PCF_TempFile.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Delete_PCF_TempFile.f

Gen_Modis_FileName.o: $(PATH_SRC_SDST)/Gen_Modis_FileName.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Gen_Modis_FileName.f

Get_date_time.o: $(PATH_SRC_SDST)/Get_date_time.f
	$(F90) $(F90FLAGS) $(ADD_F90FLAGS) $(PATH_SRC_SDST)/Get_date_time.f

Met_Common_Atmos.o: $(PATH_SRC_SDST)/Met_Common_Atmos.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Met_Common_Atmos.f

MODIS_IO_GEN_OPEN.o: $(PATH_SRC_SDST)/MODIS_IO_GEN_OPEN.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/MODIS_IO_GEN_OPEN.f

MODIS_IO_GEN_CLOSE.o: $(PATH_SRC_SDST)/MODIS_IO_GEN_CLOSE.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/MODIS_IO_GEN_CLOSE.f

MODIS_SMF_SETDYNAMICMSG_V2.1.o: $(PATH_SRC_SDST)/MODIS_SMF_SETDYNAMICMSG_V2.1.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/MODIS_SMF_SETDYNAMICMSG_V2.1.f

Parse_ECS_DateTime.o: $(PATH_SRC_SDST)/Parse_ECS_DateTime.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Parse_ECS_DateTime.f

Set_ArchiveMetadata_V2.1.o: $(PATH_SRC_SDST)/Set_ArchiveMetadata_V2.1.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Set_ArchiveMetadata_V2.1.f

Set_CoreMetadata_V2.1.o: $(PATH_SRC_SDST)/Set_CoreMetadata_V2.1.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Set_CoreMetadata_V2.1.f

STRING_LOC.o: $(PATH_SRC_SDST)/STRING_LOC.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/STRING_LOC.f

Write_ECSMetadata_nonHDF.o: $(PATH_SRC_SDST)/Write_ECSMetadata_nonHDF.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/Write_ECSMetadata_nonHDF.f

chk_input_L2.o: $(PATH_SRC_SDST)/chk_input_L2.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/chk_input_L2.f

message_1.o: $(PATH_SRC_SDST)/message_1.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/message_1.f

read_reynsst.o: $(PATH_SRC_SDST)/read_reynsst.f $(INC_FILES_SHARED)
	case "$(BRAND)" in \
          sgi32 | sgi64 ) \
             $(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/read_reynsst.f ;; \
          linux ) \
             $(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) -byteswapio $(PATH_SRC_SDST)/read_reynsst.f ;; \
          * ) \
          echo "  ERROR: Environment variable BRAND (set to \"$(BRAND)\") not recognized." >&2 ; \
          exit 1 ;; \
        esac

strlen.o: $(PATH_SRC_SDST)/strlen.f
	$(F77) $(F77FLAGS) $(ADD_F77FLAGS) $(INC) $(PATH_SRC_SDST)/strlen.f
#********************** END OF MAKEFILE ***************************
