#!/bin/ksh

# Get the NISE ancillary data file closest to a MODIS granule date and time

# Check number of arguments
if [ $# != 2 ]; then
  echo "Usage: get_nise dir date"
  echo "  dir  is the directory containing the NISE files"
  echo "  date is the date (yyyyddd)"
  exit 1
fi

# Get arguments
dir=$1
date=$2

# Find the closest date within a 7 day window, centered on the following day
for delta in 0 1 2 3; do

  list="- +"
  for sign in $list; do
  
    # Compute the Gregorian date (yyyymmdd) of the closest NISE file
    modis_date=`dateplus.exe -J $date`
    modis_date=`dateplus.exe +1 $modis_date`
    nise_date=`dateplus.exe $sign$delta $modis_date`

    # Find the NISE file
    nise_name="NISE_SSMIF13_"${nise_date}".HDFEOS"
    nise_file=`find $dir -size +2100000c -name $nise_name`
 
    # Check for success
    if [[ $nise_file != "" ]]; then
      echo $nise_file
      exit 0
    fi
    
  done
  
done

# If we get here, no matching NISE file was found
exit 1
