C-----------------------------------------------------------------------
C !F77-INC
C
C !DESCRIPTION:  Include file used by version 2 level 1B reader.
C
C !REVISION HISTORY:
C
C !TEAM-UNIQUE HEADER:
C
C    This software is developed by the MODIS Science Data Support
C    Team for the National Aeronautics and Space Administration,
C    Goddard Space Flight Center, under contract NAS5-32373.
C
C !REFERENCES AND CREDITS:
C
C !END
C---------------------------------------------------------------------


c-------------------------------------------------------------------------------
c MODIS instrument characteristics
c-------------------------------------------------------------------------------

c detector lines per scan by resolution
      integer        LINES_PER_SCAN_250M,      LINES_PER_SCAN_500M,      LINES_PER_SCAN_1KM
      parameter     (LINES_PER_SCAN_250M = 40, LINES_PER_SCAN_500M = 20, LINES_PER_SCAN_1KM = 10)

c MODIS band numbering
      integer        FIRST_MODIS_BAND,   LAST_MODIS_BAND,
     1               FIRST_250M_BAND,    LAST_250M_BAND,
     2               FIRST_500M_BAND,    LAST_500M_BAND,
     3               FIRST_1KM_BAND,     LAST_1km_BAND,
     4               FIRST_SOLAR_BAND,   LAST_SOLAR_BAND,
     5               FIRST_THERMAL_BAND, LAST_THERMAL_BAND

      parameter     (FIRST_MODIS_BAND   =  1, LAST_MODIS_BAND   = 36,
     1               FIRST_250M_BAND    =  1, LAST_250M_BAND    =  2,
     2               FIRST_500M_BAND    =  3, LAST_500M_BAND    =  7,
     3               FIRST_1KM_BAND     =  8, LAST_1km_BAND     = 36,
     4               FIRST_SOLAR_BAND   =  1, LAST_SOLAR_BAND   = 26,
     5               FIRST_THERMAL_BAND = 20, LAST_THERMAL_BAND = 36)

c frame definition
      integer        PIXELS_PER_FRAME_250M
      parameter     (PIXELS_PER_FRAME_250M = 16)


c-------------------------------------------------------------------------------
c L1B HDF product parameters
c-------------------------------------------------------------------------------

c Earth View (EV) array names
      integer    MAX_L1B_NAME_SIZE
      parameter (MAX_L1B_NAME_SIZE = 40)

      character*(MAX_L1B_NAME_SIZE) EV_name(4,3)
     1            / 'EV_250_RefSB', 3*' ',
     2              'EV_250_Aggr500_RefSB', 'EV_500_RefSB', 2*' ',
     3              'EV_250_Aggr1km_RefSB', 'EV_500_Aggr1km_RefSB', 'EV_1KM_RefSB', 'EV_1KM_Emissive' /

c EV slope and offset attribute names
      character*(MAX_L1B_NAME_SIZE) Name_of_Scale(3)
     1            / 'reflectance_scales',
     2              'radiance_scales',
     3              'corrected_counts_scales' /

      character*(MAX_L1B_NAME_SIZE) Name_of_Offset(3)
     1            / 'reflectance_offsets',
     2              'radiance_offsets',
     3              'corrected_counts_offsets' /

c Uncertainty array names
      character*(MAX_L1B_NAME_SIZE) UN_name(4,3)
     1            / 'EV_250_RefSB_Uncert_Indexes', 3*' ',
     2              'EV_250_Aggr500_RefSB_Uncert_Indexes', 'EV_500_RefSB_Uncert_Indexes', 2*' ',
     3              'EV_250_Aggr1km_RefSB_Uncert_Indexes', 'EV_500_Aggr1km_RefSB_Uncert_Indexes',
     4              'EV_1KM_RefSB_Uncert_Indexes',         'EV_1KM_Emissive_Uncert_Indexes'/

c Sample Size array names
      character*(MAX_L1B_NAME_SIZE) Sa_name(4,3)
     1           / 4*' ',
     2            'EV_250_Aggr500_RefSB_Samples_Used', 3*' ',
     3            'EV_250_Aggr1km_RefSB_Samples_Used', 'EV_500_Aggr1km_RefSB_Samples_Used', 2*' '/

c dimension names
      character*(MAX_L1B_NAME_SIZE) Dim_Name(4)
     1           /  'Band_250M:MODIS_SWATH_Type_L1B',
     2              'Band_500M:MODIS_SWATH_Type_L1B',
     3              'Band_1KM_RefSB:MODIS_SWATH_Type_L1B',
     4              'Band_1KM_Emissive:MODIS_SWATH_Type_L1B' /

c dimension numbers
      integer        DIM_NUM_XTRACK,     DIM_NUM_TRACK,     DIM_NUM_CH
      parameter     (DIM_NUM_XTRACK = 1, DIM_NUM_TRACK = 2, DIM_NUM_CH = 3)

c missing data identifier in L1B product
      integer*2      L1B_MISSING
      parameter     (L1B_MISSING = -1)


c-------------------------------------------------------------------------------
c L1B reader parameters
c-------------------------------------------------------------------------------

c valid/invalid data identifiers in L1B reader output
      byte           L1B_INVALID,      L1B_VALID
      parameter     (L1B_INVALID = -1, L1B_VALID = 0)

c fail and success defined
      integer        FAIL,     SUCCEED
      parameter     (FAIL=-1,  SUCCEED = 0)

c array configuration parameters
      integer        MAX_NUM_ARRAYS,     MAX_NUM_DIMS,     MAX_NUM_CHANNELS
      parameter     (MAX_NUM_ARRAYS = 4, MAX_NUM_DIMS = 3, MAX_NUM_CHANNELS = 16)

c calibration types and number of spatial resolutions
      integer        MAX_NUM_CAL_TYPES,     NUM_L1B_FILES
      parameter     (MAX_NUM_CAL_TYPES = 3, NUM_L1B_FILES = 3)

c define oversize static buffer
      integer        MAX_FRAMES_PER_SCAN
      parameter     (MAX_FRAMES_PER_SCAN=1500)

c identify spatial resolution factors
      integer        RESOL_IS_250M,      RESOL_IS_500M,     RESOL_IS_1KM
      parameter     (RESOL_IS_250M = 16, RESOL_IS_500M = 4, RESOL_IS_1KM = 1)

c identify bands 13 and 14
      integer        BAND_IS_14,      BAND_IS_13
      parameter     (BAND_IS_14 = 14, BAND_IS_13 = 13)

c define band gain types (used only for channels 13 and 14)
      character*(*)  HIGH_GAIN,       LOW_GAIN
      parameter     (HIGH_GAIN = 'H', LOW_GAIN = 'L')

      character*(*)  CAL_IS_COUNT,            CAL_IS_REFL,          CAL_IS_RAD
      parameter     (CAL_IS_COUNT = 'counts', CAL_IS_REFL = 'refl', CAL_IS_RAD = 'rad')
