       SUBROUTINE GET_SPEC_INFO (PROGRAMNAME, INPUTNAME,
     $        LONG_NAME, DIMLIST, UNITS_STR, VALID_RANGE, FILL_VALUE,
     $        NUMBERTYPE, SCALE_FACTOR, ADD_OFFSET, PARAM_TYPE,
     $        CELL_ACROSS_SWATH_SAMPLING, CELL_ALONG_SWATH_SAMPLING,
     $        DESCRIPTION, DESCCOUNT, TITLE, TITLECOUNT,
     $        HISTORY, HISTORYCOUNT, GEOLOCATION_POINTER)

       implicit none
       save

c---------------------------------------------------------------------
C!F77
c
c!DESCRIPTION:
c   Subroutine which extracts the correct file spec information
c   and creates an HDF output file for MOD35, MOD07, or MOD06.
c
c!INPUT PARAMETERS:
c   ProgramName   Ouput hdf file name
c   InputName     Name of Input SDS
c
c!OUTPUT PARAMETERS:
c   long_name                   HDF long name of SDS
c   dimlist                     Dimension list for SDS
c   units_str                   Unit of current SDS
c   valid_range                 Valid range of current SDS
c   Fill_Value                  Missing data value for given SDS
c   NumberType                  Type of data for current SDS
c   scale_factor                Scale factor for current SDS
c   add_offset                  Add/offset values for current SDS
c   Param_Type                  Parameter type of current SDS
c   Cell_Across_Swath_Sampling  Sampling for current SDS
c   Cell_Along_Swath_Sampling   Sampling for current SDS
c   description                 SDS description
c   DescCount                   Number of lines to be included in description
c   title                       SDS title
c   TitleCount                  Number of title lines
c   history                     SDS history summary information
c   HistoryCount                Number of history lines
c   Geolocation_Pointer         SDS geolocation pointer
c
c!REVISION HISTORY:
c   This FORTRAN source file is created by spec2fort.c
c   spec2fort.c was designed by Walter.Wolf@ssec.wisc.edu
c
c!TEAM-UNIQUE HEADER:
c
c!REFERENCES AND CREDITS:
c
c!END
c---------------------------------------------------------------------

       include 'mapi.inc'

       include 'hdf.inc'

       include 'dffunc.inc'

       character*(*) ProgramName, InputName, Geolocation_Pointer
       character*(*) long_name, units_str, Param_Type, dimlist
       double precision valid_range(*), Fill_Value
       double precision scale_factor, add_offset
       integer Cell_Across_Swath_Sampling(*)
       integer Cell_Along_Swath_Sampling(*)
       character*(*) title, history
       character*(*) description(*)
       integer TitleCount, HistoryCount, DescCount, NumberType

       integer unlimited
       integer Number_of_Instrument_Scans
       integer Maximum_Number_of_1km_Frames
       character*5 Satellite_Name
       character*5 Instrument_Name
       character*17 Grid_Type
       character*5 Grid_Resolution
       character*9 Start_of_Compositing_Period
       character*9 End_of_Compositing_Period
       integer Files_Used_In_Compositing
       character*9 File_Creation_Date
       character*18 Bands
       character*17 Lat_Resolution
       integer Granule_Start_TAI
       integer Granule_End_TAI

       unlimited = 0
       TitleCount = 0
       HistoryCount = 0
       if (ProgramName .EQ. "MOD06") then
          
          Number_of_Instrument_Scans = 203
          Maximum_Number_of_1km_Frames = 1354
          TitleCount = 1
          title = "MODIS Level 2 Cloud Properties"
          HistoryCount = 1
          history = "$Id: get_spec_info.f,v 1.1 2006/02/07 22:47:44 gumley Exp $"
          
          if (InputName .EQ. "Band_Number") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Band_Number"
             long_name = 
     $ "MODIS Band Number" 
             units_str = "none" 
             Geolocation_Pointer = "Geolocation data not applicable" 
          End If

          if (InputName .EQ. "Statistics_1km") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistic_Parameter_1km"
             long_name = 
     $ "Granule Statistics for parameters at 1x1 resolution" 
             units_str = "see description attribute" 
             Fill_Value = -999.9 
             description(1) = "\n"
             description(2) = 
     $ "Statistics_1km:" 
             description(3) = 
     $ "  1. Successful Retrieval Rate (%)" 
             description(4) = 
     $ "  2. Land Cover Fraction (%)" 
             description(5) = 
     $ "  3. Water Cover Fraction (%)" 
             description(6) = 
     $ "  4. Snow Cover Fraction (%)" 
             description(7) = 
     $ "  5. Cloud Cover Fraction (%)" 
             description(8) = 
     $ "  6. Water Cloud Detected (%)" 
             description(9) = 
     $ "  7. Ice Cloud Detected (%)" 
             description(10) = 
     $ "  8. Mean of Water Cloud Optical Thickness" 
             description(11) = 
     $ "  9. Standard Deviation of Water Cloud Optical Thickness" 
             description(12) = 
     $ "  10.Mean of Ice Cloud Optical Thickness" 
             description(13) = 
     $ "  11.Standard Deviation of Ice Cloud Optical Thickness" 
             description(14) = 
     $ "  12.Mean of Water Cloud Effective Particle Radius (microns)" 
             description(15) = 
     $ "  13.Standard Deviation of Water Cloud Effective Particle Radius " // 
     $ " (microns)"
             description(16) = 
     $ "  14.Mean of Ice Cloud Effective Diameter (microns)" 
             description(17) = 
     $ "  15.Standard Deviation of Ice Cloud Effective Diameter (microns)" 
             DescCount = 17 
          End If

          if (InputName .EQ. "Scan_Start_Time") then
             NumberType = DFNT_FLOAT64
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "TAI time at start of scan replicated across the swath" 
             units_str = "seconds since 1993-1-1 00:00:00.0 0" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.1558e9 
             Fill_Value = -999.9 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Geolocation data not applicable" 
          End If

          if (InputName .EQ. "Latitude") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Geodetic Latitude" 
             units_str = "degrees_north" 
             valid_range(1) = -90.0 
             valid_range(2) = 90.0 
             Fill_Value = -999.0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Longitude") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Geodetic Longitude" 
             units_str = "degrees_east" 
             valid_range(1) = -180.0 
             valid_range(2) = 180.0 
             Fill_Value = -999.0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Solar_Zenith") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Solar Zenith Angle, Cell to Sun" 
             units_str = "degrees" 
             valid_range(1) = 0 
             valid_range(2) = 18000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Solar_Azimuth") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Solar Azimuth Angle, Cell to Sun" 
             units_str = "degrees" 
             valid_range(1) = -18000 
             valid_range(2) = 18000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Sensor_Zenith") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Sensor Zenith Angle, Cell to Sensor" 
             units_str = "degrees" 
             valid_range(1) = 0 
             valid_range(2) = 18000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Sensor_Azimuth") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Sensor Azimuth Angle, Cell to Sensor" 
             units_str = "degrees" 
             valid_range(1) = -18000 
             valid_range(2) = 18000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Brightness_Temperature") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km,Band_Number"
             long_name = 
     $ "Brightness Temperature" 
             units_str = "K" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Surface_Temperature") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Surface Temperature" 
             units_str = "K" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Surface_Pressure") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Surface Pressure" 
             units_str = "hPa" 
             valid_range(1) = 8000 
             valid_range(2) = 11000 
             Fill_Value = -32768 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Processing_Flag") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Retrieval Method Flag" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 3 
             Fill_Value = 127 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Height_Method") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Height Method" 
             units_str = "none" 
             valid_range(1) = 1 
             valid_range(2) = 6 
             Fill_Value = 127 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Pressure") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Top Pressure" 
             units_str = "hPa" 
             valid_range(1) = 10 
             valid_range(2) = 11000 
             Fill_Value = -32768 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Pressure_Night") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Top Pressure Night" 
             units_str = "hPa" 
             valid_range(1) = 10 
             valid_range(2) = 11000 
             Fill_Value = -32768 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Pressure_Day") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Top Pressure Day" 
             units_str = "hPa" 
             valid_range(1) = 10 
             valid_range(2) = 11000 
             Fill_Value = -32768 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Temperature") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Top Temperature" 
             units_str = "K" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Temperature_Night") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Top Temperature Night" 
             units_str = "K" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Temperature_Day") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Top Temperature Day" 
             units_str = "K" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Tropopause_Height") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Tropopause Height" 
             units_str = "hPa" 
             valid_range(1) = 10 
             valid_range(2) = 11000 
             Fill_Value = -32768 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Fraction") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Fraction" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 100 
             Fill_Value = 127 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Fraction_Night") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Fraction Night" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 100 
             Fill_Value = 127 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Fraction_Day") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Fraction Day" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 100 
             Fill_Value = 127 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Effective_Emissivity") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Effective Emissivity" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 100 
             Fill_Value = 127 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Effective_Emissivity_Night") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Effective Emissivity Night" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 100 
             Fill_Value = 127 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Effective_Emissivity_Day") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Effective Emissivity Day" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 100 
             Fill_Value = 127 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Pressure_Infrared") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Top Pressure from IR Window" 
             units_str = "hPa" 
             valid_range(1) = 10 
             valid_range(2) = 11000 
             Fill_Value = -32768 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Spectral_Cloud_Forcing") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km,Band_Forcing"
             long_name = 
     $ "Spectral Cloud Forcing" 
             units_str = "Watts/meter2/steradian/micron" 
             valid_range(1) = -2000 
             valid_range(2) = 2000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Top_Pressure_From_Ratios") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km,Band_Ratio"
             long_name = 
     $ "Cloud Top Pressure from Ratios (36/35, 35/34, 35/33, 34/33, 33/31)" 
             units_str = "hPa" 
             valid_range(1) = 10 
             valid_range(2) = 11000 
             Fill_Value = -32768 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Surface_Type") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Surface Type Based on Emissivity " 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 200 
             Fill_Value = -32768 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Radiance_Variance") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km,Band_Number"
             long_name = 
     $ "Radiance Variance " 
             units_str = "Watts/meter2/steradian/micron " 
             valid_range(1) = 0 
             valid_range(2) = 20 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Brightness_Temperature_Difference") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km,Band_Difference"
             long_name = 
     $ "Brightness Temperature Difference (29-31, 31-32)" 
             units_str = "K" 
             valid_range(1) = -2000 
             valid_range(2) = 30000 
             Fill_Value = -32768 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Phase_Infrared") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Phase Infrared" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 6 
             Fill_Value = 127 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Phase_Infrared_Night") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Phase Infrared Night" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 6 
             Fill_Value = 127 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Phase_Infrared_Day") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Cloud Phase Infrared Day" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 6 
             Fill_Value = 127 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Effective_Radius") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Particle Effective Radius two-" //
     $ "channel retrieval using band 7 and either band 1, 2, or 5 (specified in Quality_Assurance_1km)"
             units_str = "micron" 
             valid_range(1) = 0 
             valid_range(2) = 10000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Optical_Thickness") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Optical Thickness two-" //
     $ "channel retrieval using band 7 and either band 1, 2, or 5 (specified in Quality_Assurance_1km)"
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 10000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Effective_Radius_1621") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Particle Effective Radius two-" //
     $ "channel retrieval using band 7 and band 6"
             units_str = "micron" 
             valid_range(1) = 0 
             valid_range(2) = 10000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Optical_Thickness_1621") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Optical Thickness two-" //
     $ "channel retrieval using band 7 and band 6 "
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 10000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Effective_Radius_Difference") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km,Radius_Difference"
             long_name = 
     $ "Cloud Particle Effective Radius two-channel retrieval using band 6 and band 20 differenced " //
     $ "from band 7 retrieval and either band 1, 2, or 5 (specified in Quality_Assurance_1km). " //
     $ "Plane 1 of SDS is band 6 - band 7 retrieval, Plane 2 is band 20 - band 7 retrieval."
             units_str = "micron" 
             valid_range(1) = -10000 
             valid_range(2) = 10000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Water_Path") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Column Water Path two-" //
     $ "band retrieval using band 7 and either band 1, 2, or 5 (specified in Quality_Assurance_1km)"
             units_str = "g/m^2" 
             valid_range(1) = 0 
             valid_range(2) = 10000 
             Fill_Value = -9999 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Water_Path_1621") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Column Water Path two-" //
     $ "band retrieval using band 7 and band 6"
             units_str = "g/m^2" 
             valid_range(1) = 0 
             valid_range(2) = 10000 
             Fill_Value = -9999 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Effective_Radius_Uncertainty") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Effective Particle Radius Relative Uncertainty (Percent)" 
             units_str = "percent" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
             scale_factor = .01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Optical_Thickness_Uncertainty") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Optical Thickness Relative Uncertainty (Percent)" 
             units_str = "percent" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
             scale_factor = .01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Water_Path_Uncertainty") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Water Path Relative Uncertainty (Percent)" 
             units_str = "percent" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
             scale_factor = .01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Effective_Radius_Uncertainty_1621") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Effective Particle Radius Relative Uncertainty (Percent) using band 7 and band 6" 
             units_str = "percent" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
             scale_factor = .01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Optical_Thickness_Uncertainty_1621") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Optical Thickness Relative Uncertainty (Percent) using band 7 and band 6" 
             units_str = "percent" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
             scale_factor = .01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Water_Path_Uncertainty_1621") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Water Path Relative Uncertainty (Percent) using band 7 and band 6" 
             units_str = "percent" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
             scale_factor = .01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Phase_Optical_Properties") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Phase Determination Used in Optical Thickness/Effective Radius Retrieval" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 4 
             Fill_Value = 0 
             scale_factor = 1. 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cloud_Multi_Layer_Flag") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cloud Multi Layer Identification From MODIS Shortwave Observations" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 9 
             Fill_Value = 0 
             scale_factor = 1. 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
             description(1) = "\n"
             description(2) = 
     $ " " 
             description(3) = 
     $ " Flag for multi-layer multi-phase cloud situations. Values 2 through 8" 
             description(4) = 
     $ " indicate the success of various multi-layer cloud tests. Value of 0" 
             description(5) = 
     $ " indicates no retrieval, value of 1 indicates single layer cloud. The" 
             description(6) = 
     $ " other values are of increasing confidence level. The value of 2 is" 
             description(7) = 
     $ " of absolute lowest confidence and often can be ignored as it " // 
     $ " is a result"
             description(8) = 
     $ " of cloud phase comparison test, which is not always trustworthy." 
             DescCount = 8 
          End If

          if (InputName .EQ. "Cirrus_Reflectance") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cirrus Reflectance" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 8000 
             Fill_Value = -9999 
             scale_factor = 0.0002 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
          End If

          if (InputName .EQ. "Cirrus_Reflectance_Flag") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Cirrus Reflectance Flag" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 3 
             Fill_Value = 157 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
             description(1) = "0: bad data, 1: non-cirrus pixel, 2: cirrus pixel, 3: contrail pixel"
             DescCount = 1 
          End If

          if (InputName .EQ. "Cloud_Mask_5km") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "MODIS Cloud Mask, First Byte" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             description(1) = "\n"
             description(2) = 
     $ " " 
             description(3) = 
     $ " Bit fields within each byte are numbered from the left:" 
             description(4) = 
     $ " 7, 6, 5, 4, 3, 2, 1, 0." 
             description(5) = 
     $ " The left-most bit (bit 7) is the most significant bit." 
             description(6) = 
     $ " The right-most bit (bit 0) is the least significant bit." 
             description(7) = 
     $ " " 
             description(8) = 
     $ " bit field       Description                             Key" 
             description(9) = 
     $ " ---------       -----------                             ---" 
             description(10) = 
     $ " " 
             description(11) = 
     $ " 0               Cloud Mask Flag                      0 = Not " // 
     $ " determined"
             description(12) = 
     $ "                                                      1 = Determined" 
             description(13) = 
     $ " " 
             description(14) = 
     $ " 2, 1            Unobstructed FOV Quality Flag        00 = Cloudy" 
             description(15) = 
     $ "                                                      01 = Uncertain" 
             description(16) = 
     $ "                                                      10 = Probably " // 
     $ " Clear"
             description(17) = 
     $ "                                                      11 = Confident " // 
     $ " Clear"
             description(18) = 
     $ "                 PROCESSING PATH" 
             description(19) = 
     $ "                 ---------------" 
             description(20) = 
     $ " 3               Day or Night Path                    0 = Night " // 
     $ " / 1 = Day"
             description(21) = 
     $ " 4               Sunglint Path                        0 = Yes " // 
     $ "   / 1 = No"
             description(22) = 
     $ " 5               Snow/Ice Background Path             0 = Yes " // 
     $ "   / 1 = No"
             description(23) = 
     $ " 7, 6            Land or Water Path                   00 = Water" 
             description(24) = 
     $ "                                                      01 = Coastal" 
             description(25) = 
     $ "                                                      10 = Desert" 
             description(26) = 
     $ "                                                      11 = Land" 
             DescCount = 26 
          End If

          if (InputName .EQ. "Quality_Assurance_5km") then
             NumberType = DFNT_INT8
             DimList = 
     $ "QA_Parameter_5km,Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Quality Assurance at 5x5 Resolution" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             description(1) = "See MODIS atmosphere QA plan for details"
             Geolocation_Pointer = "Internal geolocation arrays" 
             DescCount = 1 
          End If

          if (InputName .EQ. "Cloud_Mask_1km") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cloud_Mask_1km_Num_Bytes,Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "MODIS Cloud Mask, L2 MOD06 QA Plan" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             description(1) = "See MODIS atmosphere QA plan for details"
             Geolocation_Pointer = "External MODIS geolocation product" 
             DescCount = 1 
          End If

          if (InputName .EQ. "Quality_Assurance_1km") then
             NumberType = DFNT_INT8
             DimList = 
     $ "QA_Parameter_1km,Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Quality Assurance at 1x1 Resolution" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
             description(1) = "\n"
             description(2) = 
     $ " " 
             description(3) = 
     $ "Quality Assurance 1km reports on Cloud Optical Properties" 
             description(4) = 
     $ "algorithm performance.  Refer to MOD_PR06OD User Documentation and the" 
             description(5) = 
     $ "MODIS atmosphere QA plan for complete descriptions and coding examples." 
             description(6) = 
     $ " " 
             description(7) = 
     $ " Bit fields within each byte are numbered from the left:" 
             description(8) = 
     $ " 7, 6, 5, 4, 3, 2, 1, 0." 
             description(9) = 
     $ " The left-most bit (bit 7) is the most significant bit." 
             description(10) = 
     $ " The right-most bit (bit 0) is the least significant bit." 
             description(11) = 
     $ " " 
             description(12) = 
     $ " " 
             description(13) = 
     $ " Byte 0" 
             description(14) = 
     $ " ------" 
             description(15) = 
     $ " " 
             description(16) = 
     $ " bit field       Description                             Key" 
             description(17) = 
     $ " ---------       -----------                             ---" 
             description(18) = 
     $ " " 
             description(19) = 
     $ " Byte 0 -----------------------------------------------------------------" 
             description(20) = 
     $ "  0              Optical Thickness General QA       0 = Not Useful" 
             description(21) = 
     $ "                                                    1 = Useful" 
             description(22) = 
     $ "  2,1            Optical Thickness Confidence QA    00 = No confidence" 
             description(23) = 
     $ "                                                    01 = Marginal" 
             description(24) = 
     $ "                                                    10 = Good" 
             description(25) = 
     $ "                                                    11 = Very Good" 
             description(26) = 
     $ "  4,3            Optical Thickness out-of-bounds    00 = OT < 100" 
             description(27) = 
     $ "                                                    01 = 100 < OT < 150" 
             description(28) = 
     $ "                                                    10 = OT > 150" 
             description(29) = 
     $ "                                                    11 = Albedo " // 
     $ " too high"
             description(30) = 
     $ "  5              Effective Radius General QA        0 = Not Useful" 
             description(31) = 
     $ "                                                    1 = Useful" 
             description(32) = 
     $ "  7,6            Effective Radius Confidence QA     00 = No confidence" 
             description(33) = 
     $ "                                                    01 = Marginal" 
             description(34) = 
     $ "                                                    10 = Good" 
             description(35) = 
     $ "                                                    11 = Very Good" 
             description(36) = 
     $ " Byte 1 -----------------------------------------------------------------" 
             description(37) = 
     $ "  0              Liquid Water Path General QA       0 = Not Useful" 
             description(38) = 
     $ "                                                    1 = Useful" 
             description(39) = 
     $ "  2,1            Liquid Water Path Confidence QA    00 = No confidence" 
             description(40) = 
     $ "                                                    01 = Marginal" 
             description(41) = 
     $ "                                                    10 = Good" 
             description(42) = 
     $ "                                                    11 = Very Good" 
             description(43) = 
     $ "  5,4,3          1621 Retrieval processing path     000 = No Cloud Mask" 
             description(44) = 
     $ "                                                    001 = No Cloud" 
             description(45) = 
     $ "                                                    010 = Water Cloud" 
             description(46) = 
     $ "                                                    011 = Ice Cloud" 
             description(47) = 
     $ "                                                    100 = Unknown Cloud" 
             description(48) = 
     $ "  6              1621 Retrieval Outcome             0 = Failed/No " // 
     $ " attempt"
             description(49) = 
     $ "                                                    1 = Successful" 
             description(50) = 
     $ " Byte 2 -----------------------------------------------------------------" 
             description(51) = 
     $ "  2,1,0          Primary retrieval processing path  000 = No Cloud Mask" 
             description(52) = 
     $ "                                                    001 = No Cloud" 
             description(53) = 
     $ "                                                    010 = Water Cloud" 
             description(54) = 
     $ "                                                    011 = Ice Cloud" 
             description(55) = 
     $ "                                                    100 = Unknown Cloud" 
             description(56) = 
     $ "  3              Retrieval Outcome                  0 = Failed/No " // 
     $ " attempt"
             description(57) = 
     $ "                                                    1 = Successful" 
             description(58) = 
     $ "  4              Rayleigh Correction                0 = No Correction" 
             description(59) = 
     $ "                                                    1 = Correction" 
             description(60) = 
     $ "  5              Water Vapor Correction             0 = No Correction" 
             description(61) = 
     $ "                                                    1 = Correction" 
             description(62) = 
     $ "  7,6            Band Used for Optical Thickness Retrieval" 
             description(63) = 
     $ "                                                    00 = No attempt" 
             description(64) = 
     $ "                                                    01 = .645 micron" 
             description(65) = 
     $ "                                                    10 = .858 micron" 
             description(66) = 
     $ "                                                    11 = 1.24 micron" 
             description(67) = 
     $ " Byte 3 -----------------------------------------------------------------" 
             description(68) = 
     $ "  0              Optical Thickness 1621 General QA  0 = Not Useful" 
             description(69) = 
     $ "                                                    1 = Useful" 
             description(70) = 
     $ "  2,1            Optical Thickness 1621 Condifence QA" 
             description(71) = 
     $ "                                                    00 = No confidence" 
             description(72) = 
     $ "                                                    01 = Marginal" 
             description(73) = 
     $ "                                                    10 = Good" 
             description(74) = 
     $ "                                                    11 = Very Good" 
             description(75) = 
     $ "  3              Effective Radius 1621 General QA   0 = Not Useful" 
             description(76) = 
     $ "                                                    1 = Useful" 
             description(77) = 
     $ "  5,4            Effective Radius 1621 Confidence QA" 
             description(78) = 
     $ "                                                    00 = No confidence" 
             description(79) = 
     $ "                                                    01 = Marginal" 
             description(80) = 
     $ "                                                    10 = Good" 
             description(81) = 
     $ "                                                    11 = Very Good" 
             description(82) = 
     $ "  6,7            Clear Sky Restoral Type QA" 
             description(83) = 
     $ "                                       00 = Not Restored" 
             description(84) = 
     $ "                                       01 = Restored Via Edge detection" 
             description(85) = 
     $ "                                       10 = Restored Via Spatial " // 
     $ " Variance"
             description(86) = 
     $ "                                       11 = Restored Via 250m Tests" 
             description(87) = 
     $ " Byte 4 -----------------------------------------------------------------" 
             description(88) = 
     $ "  0              Water Path 1621 General QA         0 = Not Useful" 
             description(89) = 
     $ "                                                    1 = Useful" 
             description(90) = 
     $ "  2,1            Water Path 1621 Confidence QA      00 = No confidence" 
             description(91) = 
     $ "                                                    01 = Marginal" 
             description(92) = 
     $ "                                                    10 = Good" 
             description(93) = 
     $ "                                                    11 = Very Good" 
             description(94) = 
     $ "  5,4,3          Multi Layer Cloud Flag      000 = Cloud Mask Undet" 
             description(95) = 
     $ "                                             001 = Decision tree stop" 
             description(96) = 
     $ "                                             010 = single layer: water" 
             description(97) = 
     $ "                                             011 = multi layer: water" 
             description(98) = 
     $ "                                             100 = single layer: ice" 
             description(99) = 
     $ "                                             101 = multi layer: ice" 
             description(100) = 
     $ "                                             110 = single layer: " // 
     $ " unknown"
             description(101) = 
     $ "                                             111 = multi layer: unknown" 
             DescCount = 101 
          End If
       End If

       if (ProgramName .EQ. "MOD07") then
          
          Number_of_Instrument_Scans = 203
          Maximum_Number_of_1km_Frames = 1354
          TitleCount = 1
          title = "MODIS Level 2 Atmospheric Profiles"
          HistoryCount = 1
          history = "$Id: get_spec_info.f,v 1.1 2006/02/07 22:47:44 gumley Exp $"
          
          if (InputName .EQ. "Band_Number") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Band_Number"
             long_name = 
     $ "MODIS Band Number" 
             units_str = "none" 
          End If

          if (InputName .EQ. "Pressure_Level") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Pressure_Level"
             long_name = 
     $ "Pressure Levels of Profiles" 
             units_str = "hPa" 
          End If

          if (InputName .EQ. "Scan_Start_Time") then
             NumberType = DFNT_FLOAT64
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "TAI time at start of scan replicated across the swath" 
             units_str = "seconds since 1993-1-1 00:00:00.0 0" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.1558e9 
             Fill_Value = -999.9 
          End If

          if (InputName .EQ. "Latitude") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Geodetic Latitude" 
             units_str = "degrees_north" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -90.0 
             valid_range(2) = 90.0 
             Fill_Value = -999.9 
          End If

          if (InputName .EQ. "Longitude") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Geodetic Longitude" 
             units_str = "degrees_east" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -180.0 
             valid_range(2) = 180.0 
             Fill_Value = -999.9 
          End If

          if (InputName .EQ. "Solar_Zenith") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Solar Zenith Angle, Cell to Sun" 
             units_str = "degrees" 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 18000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Solar_Azimuth") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Solar Azimuth Angle, Cell to Sun" 
             units_str = "degrees" 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -18000 
             valid_range(2) = 18000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Sensor_Zenith") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Sensor Zenith Angle, Cell to Sensor" 
             units_str = "degrees" 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 18000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Sensor_Azimuth") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Sensor Azimuth Angle, Cell to Sensor" 
             units_str = "degrees" 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -18000 
             valid_range(2) = 18000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Brightness_Temperature") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath,Band_Number"
             long_name = 
     $ "Brightness Temperature" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Cloud_Mask") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "MODIS Cloud Mask, First Byte" 
             units_str = "none" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             description(1) = "\n"
             description(2) = 
     $ " " 
             description(3) = 
     $ " Bit fields within each byte are numbered from the left:" 
             description(4) = 
     $ " 7, 6, 5, 4, 3, 2, 1, 0." 
             description(5) = 
     $ " The left-most bit (bit 7) is the most significant bit." 
             description(6) = 
     $ " The right-most bit (bit 0) is the least significant bit." 
             description(7) = 
     $ " " 
             description(8) = 
     $ " bit field       Description                             Key" 
             description(9) = 
     $ " ---------       -----------                             ---" 
             description(10) = 
     $ " " 
             description(11) = 
     $ " 0               Cloud Mask Flag                      0 = Not " // 
     $ " determined"
             description(12) = 
     $ "                                                      1 = Determined" 
             description(13) = 
     $ " " 
             description(14) = 
     $ " 2, 1            Unobstructed FOV Quality Flag        00 = Cloudy" 
             description(15) = 
     $ "                                                      01 = Uncertain" 
             description(16) = 
     $ "                                                      10 = Probably " // 
     $ " Clear"
             description(17) = 
     $ "                                                      11 = Confident " // 
     $ " Clear"
             description(18) = 
     $ "                 PROCESSING PATH" 
             description(19) = 
     $ "                 ---------------" 
             description(20) = 
     $ " 3               Day or Night Path                    0 = Night " // 
     $ " / 1 = Day"
             description(21) = 
     $ " 4               Sunglint Path                        0 = Yes " // 
     $ "   / 1 = No"
             description(22) = 
     $ " 5               Snow/Ice Background Path             0 = Yes " // 
     $ "   / 1 = No"
             description(23) = 
     $ " 7, 6            Land or Water Path                   00 = Water" 
             description(24) = 
     $ "                                                      01 = Coastal" 
             description(25) = 
     $ "                                                      10 = Desert" 
             description(26) = 
     $ "                                                      11 = Land" 
             DescCount = 26 
          End If

          if (InputName .EQ. "Surface_Temperature") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Surface Temperature" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Surface_Pressure") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Surface Pressure" 
             units_str = "hPa" 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 8000 
             valid_range(2) = 11000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Surface_Elevation") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Surface Elevation" 
             units_str = "m" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -400 
             valid_range(2) = 8840 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Processing_Flag") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Processing Flag" 
             units_str = "none" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 1 
             Fill_Value = 127 
          End If

          if (InputName .EQ. "Tropopause_Height") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Tropopause Height" 
             units_str = "hPa" 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 10 
             valid_range(2) = 11000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Guess_Temperature_Profile") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath,Pressure_Level"
             long_name = 
     $ "Guess Temperature Profile" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Guess_Moisture_Profile") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath,Pressure_Level"
             long_name = 
     $ "Guess Dew Point Temperature Profile" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "Non MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Retrieved_Temperature_Profile") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath,Pressure_Level"
             long_name = 
     $ "Retrieved Temperature Profile" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "MODIS Ouput" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Retrieved_Moisture_Profile") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath,Pressure_Level"
             long_name = 
     $ "Retrieved Dew Point Temperature Profile" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = -15000.0 
             Param_Type = "MODIS Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Retrieved_Height_Profile") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath,Pressure_Level"
             long_name = 
     $ "Retrieved Geopotential Height Profile" 
             units_str = "m" 
             scale_factor = 1.0 
             add_offset = -32500.0 
             Param_Type = "MODIS Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -32500 
             valid_range(2) = 32500 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Total_Ozone") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Total Ozone Burden" 
             units_str = "Dobson" 
             scale_factor = 0.1 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 5000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Total_Totals") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Total Totals" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 8000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Lifted_Index") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Lifted Index" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -2000 
             valid_range(2) = 4000 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "K_Index") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "K_Index" 
             units_str = "K" 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = -50 
             valid_range(2) = 650 
             Fill_Value = -32768 
          End If

          if (InputName .EQ. "Water_Vapor") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Total Column Precipitable Water Vapor - IR Retrieval" 
             units_str = "cm" 
             scale_factor = 0.001 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
          End If

          if (InputName .EQ. "Water_Vapor_Direct") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Total Column Precipitable Water Vapor - Direct IR Retrieval" 
             units_str = "cm" 
             scale_factor = 0.001 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
          End If

          if (InputName .EQ. "Water_Vapor_Low") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Precipitable Water Vapor Low - IR Retrieval" 
             units_str = "cm" 
             scale_factor = 0.001 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
          End If

          if (InputName .EQ. "Water_Vapor_High") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Precipitable Water Vapor High - IR Retrieval" 
             units_str = "cm" 
             scale_factor = 0.001 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             valid_range(1) = 0 
             valid_range(2) = 20000 
             Fill_Value = -9999 
          End If

          if (InputName .EQ. "Quality_Assurance") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Output_Parameter,Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Quality Assurance Parameters" 
             units_str = "none" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             description(1) = "\n"
             description(2) = 
     $ "                Product and Optional run time QA flags" 
             description(3) = 
     $ " " 
             description(4) = 
     $ "                   Product run time QA flags" 
             description(5) = 
     $ " QA Flag Name     Number of     Bit Value   Description" 
             description(6) = 
     $ "                    Bits" 
             description(7) = 
     $ " -------------------------------------------------------------" 
             description(8) = 
     $ " Retrieved Temperature 1            0       not useful" 
             description(9) = 
     $ "   Profile QA                       1       useful" 
             description(10) = 
     $ " " 
             description(11) = 
     $ " Retrieved Temperature 2           0-3      4 confidence" 
             description(12) = 
     $ "   Profile                                    levels" 
             description(13) = 
     $ "   Confidence QA" 
             description(14) = 
     $ " " 
             description(15) = 
     $ " Spare                1" 
             description(16) = 
     $ " " 
             description(17) = 
     $ " Retrieved Moisture   1             0       not useful" 
             description(18) = 
     $ "   Profile                          1       useful" 
             description(19) = 
     $ "   QA" 
             description(20) = 
     $ " " 
             description(21) = 
     $ " Retrieved Moisture   2            0-3      4 confidence" 
             description(22) = 
     $ "   Profile                                    levels" 
             description(23) = 
     $ "   Confidence QA" 
             description(24) = 
     $ " " 
             description(25) = 
     $ " Spare                1" 
             description(26) = 
     $ " " 
             description(27) = 
     $ " Total Ozone          1             0       not useful" 
             description(28) = 
     $ "   Burden QA                        1       useful" 
             description(29) = 
     $ " " 
             description(30) = 
     $ " Total Ozone          2            0-3      4 confidence" 
             description(31) = 
     $ "   Burden                                     levels" 
             description(32) = 
     $ "   Confidence QA" 
             description(33) = 
     $ " " 
             description(34) = 
     $ " Spare                1" 
             description(35) = 
     $ " " 
             description(36) = 
     $ " Lifted Index         1             0       not useful" 
             description(37) = 
     $ "   Stability                        1       useful" 
             description(38) = 
     $ "   Index QA" 
             description(39) = 
     $ " " 
             description(40) = 
     $ " Lifted Index         2            0-3      4 confidence" 
             description(41) = 
     $ "   Stability                                  levels" 
             description(42) = 
     $ "   Confidence QA" 
             description(43) = 
     $ " " 
             description(44) = 
     $ " Spare                1" 
             description(45) = 
     $ " " 
             description(46) = 
     $ " K Index              1             0       not useful" 
             description(47) = 
     $ "   Stability                        1       useful" 
             description(48) = 
     $ "   Index QA" 
             description(49) = 
     $ " " 
             description(50) = 
     $ " K Index              2            0-3      4 confidence" 
             description(51) = 
     $ "   Stability                                  levels" 
             description(52) = 
     $ "   Confidence QA" 
             description(53) = 
     $ " " 
             description(54) = 
     $ " Spare                1" 
             description(55) = 
     $ " " 
             description(56) = 
     $ " Total Totals         1             0       not useful" 
             description(57) = 
     $ "   Stability                        1       useful" 
             description(58) = 
     $ "   Index QA" 
             description(59) = 
     $ " " 
             description(60) = 
     $ " Total Totals         2            0-3      4 confidence" 
             description(61) = 
     $ "   Stability                                  levels" 
             description(62) = 
     $ "   Confidence QA" 
             description(63) = 
     $ " " 
             description(64) = 
     $ " Spare                1" 
             description(65) = 
     $ " ---------------------- 3 bytes total -----------------------" 
             description(66) = 
     $ " " 
             description(67) = 
     $ "   Optional run time QA flags - processing path flags" 
             description(68) = 
     $ " QA Flag Name     Number of     Bit Value   Description" 
             description(69) = 
     $ "                    Bits" 
             description(70) = 
     $ " -------------------------------------------------------------" 
             description(71) = 
     $ " Number of            8            0-25" 
             description(72) = 
     $ "   Cloudy Pixels" 
             description(73) = 
     $ "   within 5x5 km" 
             description(74) = 
     $ "   box" 
             description(75) = 
     $ " " 
             description(76) = 
     $ " Number of            8            0-25" 
             description(77) = 
     $ "   Clear Pixels" 
             description(78) = 
     $ "   within 5x5 km" 
             description(79) = 
     $ "   box" 
             description(80) = 
     $ " " 
             description(81) = 
     $ " Number of            8            0-25" 
             description(82) = 
     $ "   Missing" 
             description(83) = 
     $ "   Pixels within" 
             description(84) = 
     $ "   5x5 km box" 
             description(85) = 
     $ " " 
             description(86) = 
     $ " Method               2             0       Statistical" 
             description(87) = 
     $ "  of Profiles                       1       Physical" 
             description(88) = 
     $ "  Retrieval                         2       Other" 
             description(89) = 
     $ "                                    3       No retrieval" 
             description(90) = 
     $ " " 
             description(91) = 
     $ " Method               2             0       RTE Perturbation" 
             description(92) = 
     $ "  of Ozone                          1       Upper and Lower" 
             description(93) = 
     $ "  Retrieval                                 Stratospheric Ozone Method" 
             description(94) = 
     $ "                                    2       Other" 
             description(95) = 
     $ "                                    3       No retrieval" 
             description(96) = 
     $ " " 
             description(97) = 
     $ " Spares               4" 
             description(98) = 
     $ " ---------------   4 bytes total -----------------------------" 
             description(99) = 
     $ " " 
             description(100) = 
     $ "   Optional run time QA flags - data resource flags" 
             description(101) = 
     $ " " 
             description(102) = 
     $ " QA Flag Name     Number of     Bit Value   Description" 
             description(103) = 
     $ "                    Bits" 
             description(104) = 
     $ " -------------------------------------------------------------" 
             description(105) = 
     $ " Guess Moisture       2             0       NCEP" 
             description(106) = 
     $ "   profile                          1       DAO" 
             description(107) = 
     $ "   source                           2       AIRS/AMSU" 
             description(108) = 
     $ "                                    3       Not used" 
             description(109) = 
     $ " " 
             description(110) = 
     $ " Guess Temperature    2             0       NCEP" 
             description(111) = 
     $ "   Profile                          1       DAO" 
             description(112) = 
     $ "   source                           2       AIRS/AMSU" 
             description(113) = 
     $ "                                    3       Not used" 
             description(114) = 
     $ " " 
             description(115) = 
     $ " Surface              2             0       NCEP" 
             description(116) = 
     $ "   Temperature                      1       DAO" 
             description(117) = 
     $ "   Over Land                        2       Other" 
             description(118) = 
     $ "                                    3       Not used" 
             description(119) = 
     $ " " 
             description(120) = 
     $ " Surface              2             0       Reynolds blended" 
             description(121) = 
     $ "   Temperature                      1       DAO" 
             description(122) = 
     $ "   Over Ocean                       2       Other" 
             description(123) = 
     $ "                                    3       Not used" 
             description(124) = 
     $ " " 
             description(125) = 
     $ " Surface              2             0       NCEP" 
             description(126) = 
     $ "   Pressure                         1       DAO" 
             description(127) = 
     $ "                                    2       Other" 
             description(128) = 
     $ "                                    3       Not used" 
             description(129) = 
     $ " " 
             description(130) = 
     $ " Ozone                2             0       TOMS" 
             description(131) = 
     $ "   Profile                          1       TOVS" 
             description(132) = 
     $ "   First                            2       DAO" 
             description(133) = 
     $ "   Guess                            3       Other" 
             description(134) = 
     $ " " 
             description(135) = 
     $ " Spares              12" 
             description(136) = 
     $ " ------------------ 2 bytes total ----------------------------" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             DescCount = 136 
          End If

          if (InputName .EQ. "Quality_Assurance_Infrared") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Water_Vapor_QA_Bytes,Cell_Across_Swath,Cell_Along_Swath"
             long_name = 
     $ "Run time QA flags" 
             units_str = "none" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
             description(1) = "\n"
             description(2) = 
     $ " " 
             description(3) = 
     $ "  Water Vapor IR product and Optional run time QA flags" 
             description(4) = 
     $ " " 
             description(5) = 
     $ "                   Product run time QA flags" 
             description(6) = 
     $ " QA Flag Name     Number of     Bit Value   Description" 
             description(7) = 
     $ "                    Bits" 
             description(8) = 
     $ " -------------------------------------------------------------" 
             description(9) = 
     $ " IR Water Vapor       1             0       not useful" 
             description(10) = 
     $ "   QA                               1       useful" 
             description(11) = 
     $ " " 
             description(12) = 
     $ " IR Water Vapor       2            0-3      4 confidence" 
             description(13) = 
     $ "   Confidence QA                              levels" 
             description(14) = 
     $ " " 
             description(15) = 
     $ " Spares               5" 
             description(16) = 
     $ " ---------------------- 1 byte total -------------------------" 
             description(17) = 
     $ " " 
             description(18) = 
     $ "   Optional run time QA flags - processing path flags" 
             description(19) = 
     $ " QA Flag Name     Number of     Bit Value   Description" 
             description(20) = 
     $ "                    Bits" 
             description(21) = 
     $ " -------------------------------------------------------------" 
             description(22) = 
     $ " Number of            8            0-25" 
             description(23) = 
     $ "   Cloudy Pixels" 
             description(24) = 
     $ "   within 5x5 km" 
             description(25) = 
     $ "   box" 
             description(26) = 
     $ " " 
             description(27) = 
     $ " Number of            8            0-25" 
             description(28) = 
     $ "   Clear Pixels" 
             description(29) = 
     $ "   within 5x5 km" 
             description(30) = 
     $ "   box" 
             description(31) = 
     $ " " 
             description(32) = 
     $ " Number of            8            0-25" 
             description(33) = 
     $ "   Missing" 
             description(34) = 
     $ "   Pixels within" 
             description(35) = 
     $ "   5x5 km box" 
             description(36) = 
     $ " " 
             description(37) = 
     $ " IR Water Vapor       2             0      Split Window (11-" // 
     $ " 12) technique"
             description(38) = 
     $ "   Retrieval                        1      Integration of moisture " // 
     $ " profile"
             description(39) = 
     $ "   Method Used                      2      Other" 
             description(40) = 
     $ "                                    3      No Retrieval" 
             description(41) = 
     $ " " 
             description(42) = 
     $ " Spares               6" 
             description(43) = 
     $ " ---------------------- 4 bytes total -----------------------" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             DescCount = 43 
          End If
       End If

       if (ProgramName .EQ. "MOD35") then
          
          Number_of_Instrument_Scans = 203
          Maximum_Number_of_1km_Frames = 1354
          TitleCount = 1
          title = "MODIS Level 2 Cloud Mask"
          HistoryCount = 1
          history = "$Id: get_spec_info.f,v 1.1 2006/02/07 22:47:44 gumley Exp $"
          
          if (InputName .EQ. "Byte_Segment") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Byte_Segment"
          End If

          if (InputName .EQ. "Scan_Start_Time") then
             NumberType = DFNT_FLOAT64
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "TAI time at start of scan replicated across the swath" 
             units_str = "seconds since 1993-1-1 00:00:00.0 0" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.1558e9 
             Fill_Value = -999.9 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Latitude") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Geodetic Latitude" 
             units_str = "degrees_north" 
             valid_range(1) = -90.0 
             valid_range(2) = 90.0 
             Fill_Value = -999.99 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Longitude") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Geodetic Longitude" 
             units_str = "degrees_east" 
             valid_range(1) = -180.0 
             valid_range(2) = 180.0 
             Fill_Value = -999.99 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Solar_Zenith") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Solar Zenith Angle, Cell to Sun" 
             units_str = "degrees" 
             valid_range(1) = 0 
             valid_range(2) = 18000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Solar_Azimuth") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Solar Azimuth Angle, Cell to Sun" 
             units_str = "degrees" 
             valid_range(1) = -18000 
             valid_range(2) = 18000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Sensor_Zenith") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Sensor Zenith Angle, Cell to Sensor" 
             units_str = "degrees" 
             valid_range(1) = 0 
             valid_range(2) = 18000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Sensor_Azimuth") then
             NumberType = DFNT_INT16
             DimList = 
     $ "Cell_Across_Swath_5km,Cell_Along_Swath_5km"
             long_name = 
     $ "Sensor Azimuth Angle, Cell to Sensor" 
             units_str = "degrees" 
             valid_range(1) = -18000 
             valid_range(2) = 18000 
             Fill_Value = -9999 
             scale_factor = 0.01 
             add_offset = 0.0 
             Param_Type = "MODIS Input" 
             Cell_Across_Swath_Sampling(1) = 3 
             Cell_Across_Swath_Sampling(2) = 1348 
             Cell_Across_Swath_Sampling(3) = 5 
             Cell_Along_Swath_Sampling(1) = 3 
             Cell_Along_Swath_Sampling(2) = 2028 
             Cell_Along_Swath_Sampling(3) = 5 
             Geolocation_Pointer = "Internal geolocation arrays" 
          End If

          if (InputName .EQ. "Cloud_Mask") then
             NumberType = DFNT_INT8
             DimList = 
     $ "Cell_Across_Swath_1km,Cell_Along_Swath_1km,Byte_Segment"
             long_name = 
     $ "MODIS Cloud Mask and Spectral Test Results" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
             description(1) = "\n"
             description(2) = 
     $ " " 
             description(3) = 
     $ " Bit fields within each byte are numbered from the left:" 
             description(4) = 
     $ " 7, 6, 5, 4, 3, 2, 1, 0." 
             description(5) = 
     $ " The left-most bit (bit 7) is the most significant bit." 
             description(6) = 
     $ " The right-most bit (bit 0) is the least significant bit." 
             description(7) = 
     $ " " 
             description(8) = 
     $ " bit field       Description                             Key" 
             description(9) = 
     $ " ---------       -----------                             ---" 
             description(10) = 
     $ " " 
             description(11) = 
     $ " 0               Cloud Mask Flag                      0 = Not " // 
     $ " determined"
             description(12) = 
     $ "                                                      1 = Determined" 
             description(13) = 
     $ " " 
             description(14) = 
     $ " 2, 1            Unobstructed FOV Quality Flag        00 = Cloudy" 
             description(15) = 
     $ "                                                      01 = Uncertain" 
             description(16) = 
     $ "                                                      10 = Probably " // 
     $ " Clear"
             description(17) = 
     $ "                                                      11 = Confident " // 
     $ " Clear"
             description(18) = 
     $ "                 PROCESSING PATH" 
             description(19) = 
     $ "                 ---------------" 
             description(20) = 
     $ " 3               Day or Night Path                    0 = Night " // 
     $ " / 1 = Day"
             description(21) = 
     $ " 4               Sunglint Path                        0 = Yes " // 
     $ "   / 1 = No"
             description(22) = 
     $ " 5               Snow/Ice Background Path             0 = Yes " // 
     $ "   / 1 = No"
             description(23) = 
     $ " 7, 6            Land or Water Path                   00 = Water" 
             description(24) = 
     $ "                                                      01 = Coastal" 
             description(25) = 
     $ "                                                      10 = Desert" 
             description(26) = 
     $ "                                                      11 = Land" 
             description(27) = 
     $ " ____ END BYTE 1 ______________" // 
     $ " ___________________________________________"
             description(28) = 
     $ " " 
             description(29) = 
     $ " bit field       Description                             Key" 
             description(30) = 
     $ " ---------       -----------                             ---" 
             description(31) = 
     $ " " 
             description(32) = 
     $ "                 ADDITIONAL INFORMATION" 
             description(33) = 
     $ "                 ----------------------" 
             description(34) = 
     $ " 0               Non-" // 
     $ " cloud obstruction Flag              0 = Yes / 1 = No"
             description(35) = 
     $ " 1               Thin Cirrus Detected  (Solar)           0 = " // 
     $ " Yes / 1 = No"
             description(36) = 
     $ " 2               Shadow Found                            0 = " // 
     $ " Yes / 1 = No"
             description(37) = 
     $ " 3               Thin Cirrus Detected  (Infrared)        0 = " // 
     $ " Yes / 1 = No"
             description(38) = 
     $ " 4               Adjacent Cloud Detected **              0 = " // 
     $ " Yes / 1 = No"
             description(39) = 
     $ "                 ** Implemented Post Launch to" 
             description(40) = 
     $ "                    Indicate cloud found within" 
             description(41) = 
     $ "                    surrounding 1 km pixels *" 
             description(42) = 
     $ " " 
             description(43) = 
     $ "                 1-km CLOUD FLAGS" 
             description(44) = 
     $ "                 ----------------" 
             description(45) = 
     $ " 5               Cloud Flag -" // 
     $ "  IR Threshold               0 = Yes / 1 = No"
             description(46) = 
     $ " 6               High Cloud Flag -" // 
     $ "  CO2 Test              0 = Yes / 1 = No"
             description(47) = 
     $ " 7               High Cloud Flag -" // 
     $ "  6.7 micron Test       0 = Yes / 1 = No"
             description(48) = 
     $ " ____ END BYTE 2 ______________" // 
     $ " ___________________________________________"
             description(49) = 
     $ " " 
             description(50) = 
     $ " bit field       Description                             Key" 
             description(51) = 
     $ " ---------       -----------                             ---" 
             description(52) = 
     $ " " 
             description(53) = 
     $ " 0               High Cloud Flag -" // 
     $ "  1.38 micron Test      0 = Yes / 1 = No"
             description(54) = 
     $ " 1               High Cloud Flag - 3.7-" // 
     $ " 12 micron Test    0 = Yes / 1 = No"
             description(55) = 
     $ " 2               Cloud Flag -" // 
     $ "  IR Temperature             0 = Yes / 1 = No"
             description(56) = 
     $ "                              Difference" 
             description(57) = 
     $ " 3               Cloud Flag - 3.7-" // 
     $ " 11 micron Test         0 = Yes / 1 = No"
             description(58) = 
     $ " 4               Cloud Flag -" // 
     $ "  Visible Reflectance Test   0 = Yes / 1 = No"
             description(59) = 
     $ " 5               Cloud Flag -" // 
     $ "  Visible Reflectance        0 = Yes / 1 = No"
             description(60) = 
     $ "                              Ratio Test" 
             description(61) = 
     $ " 6               Cloud Flag -" // 
     $ "  NDVI Final Confidence      0 = Yes / 1 = No"
             description(62) = 
     $ "                              Confirmation Test" 
             description(63) = 
     $ " 7               Cloud Flag - Night 7.3-" // 
     $ " 11 micron Test   0 = Yes / 1 = No"
             description(64) = 
     $ " ____ END BYTE 3 ______________" // 
     $ " ___________________________________________"
             description(65) = 
     $ " " 
             description(66) = 
     $ " bit field       Description                             Key" 
             description(67) = 
     $ " ---------       -----------                             ---" 
             description(68) = 
     $ " " 
             description(69) = 
     $ "                 ADDITIONAL TESTS" 
             description(70) = 
     $ "                 ----------------" 
             description(71) = 
     $ " 0               Cloud Flag -" // 
     $ "  Spare                      0 = Yes / 1 = No"
             description(72) = 
     $ " 1               Cloud Flag -" // 
     $ "  Spatial Variability        0 = Yes / 1 = No"
             description(73) = 
     $ " 2               Final Confidence Confirmation Test      0 = " // 
     $ " Yes / 1 = No"
             description(74) = 
     $ " 3               Cloud Flag -" // 
     $ "  Night Water                0 = Yes / 1 = No"
             description(75) = 
     $ "                              Spatial Variability" 
             description(76) = 
     $ " 4               Suspended Dust Flag                     0 = " // 
     $ " Yes / 1 = No"
             description(77) = 
     $ " " 
             description(78) = 
     $ " 5-7             Spares" 
             description(79) = 
     $ " ____ END BYTE 4 ______________" // 
     $ " ___________________________________________"
             description(80) = 
     $ " " 
             description(81) = 
     $ " bit field       Description                             Key" 
             description(82) = 
     $ " ---------       -----------                             ---" 
             description(83) = 
     $ " " 
             description(84) = 
     $ "                 250-m Cloud Flag - Visible Tests" 
             description(85) = 
     $ "                 --------------------------------" 
             description(86) = 
     $ " 0               Element(1,1)                            0 = " // 
     $ " Yes / 1 = No"
             description(87) = 
     $ " 1               Element(1,2)                            0 = " // 
     $ " Yes / 1 = No"
             description(88) = 
     $ " 2               Element(1,3)                            0 = " // 
     $ " Yes / 1 = No"
             description(89) = 
     $ " 3               Element(1,4)                            0 = " // 
     $ " Yes / 1 = No"
             description(90) = 
     $ " 4               Element(2,1)                            0 = " // 
     $ " Yes / 1 = No"
             description(91) = 
     $ " 5               Element(2,2)                            0 = " // 
     $ " Yes / 1 = No"
             description(92) = 
     $ " 6               Element(2,3)                            0 = " // 
     $ " Yes / 1 = No"
             description(93) = 
     $ " 7               Element(2,4)                            0 = " // 
     $ " Yes / 1 = No"
             description(94) = 
     $ " ____ END BYTE 5 ______________" // 
     $ " ___________________________________________"
             description(95) = 
     $ " " 
             description(96) = 
     $ " bit field       Description                             Key" 
             description(97) = 
     $ " ----------      -----------                             ---" 
             description(98) = 
     $ " " 
             description(99) = 
     $ " 0               Element(3,1)                            0 = " // 
     $ " Yes / 1 = No"
             description(100) = 
     $ " 1               Element(3,2)                            0 = " // 
     $ " Yes / 1 = No"
             description(101) = 
     $ " 2               Element(3,3)                            0 = " // 
     $ " Yes / 1 = No"
             description(102) = 
     $ " 3               Element(3,4)                            0 = " // 
     $ " Yes / 1 = No"
             description(103) = 
     $ " 4               Element(4,1)                            0 = " // 
     $ " Yes / 1 = No"
             description(104) = 
     $ " 5               Element(4,2)                            0 = " // 
     $ " Yes / 1 = No"
             description(105) = 
     $ " 6               Element(4,3)                            0 = " // 
     $ " Yes / 1 = No"
             description(106) = 
     $ " 7               Element(4,4)                            0 = " // 
     $ " Yes / 1 = No"
             description(107) = 
     $ " ____ END BYTE 6 ______________" // 
     $ " ___________________________________________"
             DescCount = 107 
          End If

          if (InputName .EQ. "Quality_Assurance") then
             NumberType = DFNT_INT8
             DimList = 
     $ "QA_Dimension,Cell_Across_Swath_1km,Cell_Along_Swath_1km"
             long_name = 
     $ "Quality Assurance for Cloud Mask" 
             units_str = "none" 
             valid_range(1) = 0 
             valid_range(2) = 255 
             Fill_Value = 0 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "Output" 
             Cell_Across_Swath_Sampling(1) = 1 
             Cell_Across_Swath_Sampling(2) = 1354 
             Cell_Across_Swath_Sampling(3) = 1 
             Cell_Along_Swath_Sampling(1) = 1 
             Cell_Along_Swath_Sampling(2) = 2030 
             Cell_Along_Swath_Sampling(3) = 1 
             Geolocation_Pointer = "External MODIS geolocation product" 
             description(1) = "\n"
             description(2) = 
     $ "        Product Run Time QA Flags" 
             description(3) = 
     $ " QA Flag Name    Number of Bits  Bit Value   Description" 
             description(4) = 
     $ " -------------------------------------------------------------" 
             description(5) = 
     $ " Cloud Mask QA        1             0       not useful" 
             description(6) = 
     $ "   (1km)                            1       useful" 
             description(7) = 
     $ " " 
             description(8) = 
     $ " Cloud Mask           3            0-7      8 confidence levels" 
             description(9) = 
     $ "   Confidence QA" 
             description(10) = 
     $ "   (1km)" 
             description(11) = 
     $ " " 
             description(12) = 
     $ " Spares               4" 
             description(13) = 
     $ "  -------- ( 1 byte total ) --------------------------------" 
             description(14) = 
     $ " " 
             description(15) = 
     $ " Optional run time QA flags - Individual test application" 
             description(16) = 
     $ " " 
             description(17) = 
     $ " QA Flag Name    Number of Bits  Bit Value   Description" 
             description(18) = 
     $ " -------------------------------------------------------------" 
             description(19) = 
     $ " NCO test             1             0       Not Applied" 
             description(20) = 
     $ "                                    1       Applied" 
             description(21) = 
     $ " " 
             description(22) = 
     $ " Thin Cirrus          1             0       Not Applied" 
             description(23) = 
     $ "   test (Solar)                     1       Applied" 
             description(24) = 
     $ " " 
             description(25) = 
     $ " Shadow Tests         1             0       Not Applied" 
             description(26) = 
     $ "                                    1       Applied" 
             description(27) = 
     $ " " 
             description(28) = 
     $ " Thin Cirrus          1             0       Not Applied" 
             description(29) = 
     $ "   test(IR)                         1       Applied" 
             description(30) = 
     $ " " 
             description(31) = 
     $ " Cloud Adjancency     1             0       Not Applied" 
             description(32) = 
     $ "   test(IR)                         1       Applied" 
             description(33) = 
     $ " " 
             description(34) = 
     $ " IR Threshold         1             0       Not Applied" 
             description(35) = 
     $ "   test                             1       Applied" 
             description(36) = 
     $ " " 
             description(37) = 
     $ " High Cloud           1             0       Not Applied" 
             description(38) = 
     $ "   Test (CO2)                       1       Applied" 
             description(39) = 
     $ " " 
             description(40) = 
     $ " High Cloud           1             0       Not Applied" 
             description(41) = 
     $ "   Test (6.7)                       1       Applied" 
             description(42) = 
     $ " " 
             description(43) = 
     $ " High Cloud           1             0       Not Applied" 
             description(44) = 
     $ "   Test (1.38)                      1       Applied" 
             description(45) = 
     $ " " 
             description(46) = 
     $ " High Cloud           1             0       Not Applied" 
             description(47) = 
     $ "   Test (3.7-12um)                  1       Applied" 
             description(48) = 
     $ " " 
             description(49) = 
     $ " IR Temperature       1             0       Not Applied" 
             description(50) = 
     $ "   Difference Tests                 1       Applied" 
             description(51) = 
     $ " " 
             description(52) = 
     $ " 3.7-11um Test        1             0       Not Applied" 
             description(53) = 
     $ "                                    1       Applied" 
             description(54) = 
     $ " " 
             description(55) = 
     $ " .68 Reflectance      1             0       Not Applied" 
             description(56) = 
     $ "   Test                             1       Applied" 
             description(57) = 
     $ " " 
             description(58) = 
     $ " Visible Ratio        1             0       Not Applied" 
             description(59) = 
     $ "   Test                             1       Applied" 
             description(60) = 
     $ " " 
             description(61) = 
     $ " NDVI Final           1             0       Not Applied" 
             description(62) = 
     $ "   Confidence                       1       Applied" 
             description(63) = 
     $ "   Confirmation" 
             description(64) = 
     $ " " 
             description(65) = 
     $ " Spare                1             0       Not Applied" 
             description(66) = 
     $ "                                    1       Applied" 
             description(67) = 
     $ " " 
             description(68) = 
     $ " Spare                1             0       Not Applied" 
             description(69) = 
     $ "                                    1       Applied" 
             description(70) = 
     $ " " 
             description(71) = 
     $ " Spatial              1             0       Not Applied" 
             description(72) = 
     $ "   Variability Test                 1       Applied" 
             description(73) = 
     $ " " 
             description(74) = 
     $ " Final Confidence     1             0       Not Applied" 
             description(75) = 
     $ "   Confirmation Test                1       Applied" 
             description(76) = 
     $ " " 
             description(77) = 
     $ " Night Water          1             0       Not Applied" 
             description(78) = 
     $ "   Spatial Variability              1       Applied" 
             description(79) = 
     $ " " 
             description(80) = 
     $ " Suspended Dust Test  1             0       Not Applied" 
             description(81) = 
     $ "                                    1       Applied" 
             description(82) = 
     $ " " 
             description(83) = 
     $ " Spares               3" 
             description(84) = 
     $ " " 
             description(85) = 
     $ " 250 m Visible      1(16)           0       Not Applied" 
             description(86) = 
     $ "   Tests                            1       Applied" 
             description(87) = 
     $ "   (16 times as (line1,element1),(line1, element2),..." 
             description(88) = 
     $ "   (line4,element4))" 
             description(89) = 
     $ " " 
             description(90) = 
     $ "  -------- ( 5 bytes total ) --------------------------------" 
             description(91) = 
     $ " " 
             description(92) = 
     $ " Optional run time QA flags - data information flags" 
             description(93) = 
     $ " " 
             description(94) = 
     $ " QA Flag Name    Number of Bits  Bit Value   Description" 
             description(95) = 
     $ "  -------------------------------------------------------------" 
             description(96) = 
     $ " Number of            2             0       None" 
             description(97) = 
     $ "   bands used to                    1       1-7" 
             description(98) = 
     $ "   generate                         2       8-14" 
             description(99) = 
     $ "   cloud mask                       3       15-21" 
             description(100) = 
     $ " " 
             description(101) = 
     $ " Number of            2             0       None" 
             description(102) = 
     $ "   spectral                         1       1-3" 
             description(103) = 
     $ "   tests used to                    2       4-6" 
             description(104) = 
     $ "   generate                         3       7-9" 
             description(105) = 
     $ "   cloud mask" 
             description(106) = 
     $ " " 
             description(107) = 
     $ " Spares               4" 
             description(108) = 
     $ " " 
             description(109) = 
     $ "  -------- ( 1 byte total ) --------------------------------" 
             description(110) = 
     $ " " 
             description(111) = 
     $ " Optional run time QA flags - data resource flags" 
             description(112) = 
     $ " " 
             description(113) = 
     $ " QA Flag Name    Number of Bits  Bit Value   Description" 
             description(114) = 
     $ " -------------------------------------------------------------" 
             description(115) = 
     $ " Clear                2             0       MOD35" 
             description(116) = 
     $ "   Radiance                         1       Model forward calculation" 
             description(117) = 
     $ "   Origin                           2       Other" 
             description(118) = 
     $ "                                    3       Not used" 
             description(119) = 
     $ " " 
             description(120) = 
     $ " Surface              2             0       NCEP GDAS" 
             description(121) = 
     $ "   Temperature                      1       DAO" 
             description(122) = 
     $ "   Over Land                        2       MOD11" 
             description(123) = 
     $ "                                    3       Other" 
             description(124) = 
     $ " " 
             description(125) = 
     $ " Surface              2             0       Reynolds blended" 
             description(126) = 
     $ "   Temperature                      1       DAO" 
             description(127) = 
     $ "   Over Ocean                       2       MOD28" 
             description(128) = 
     $ "                                    3       Other" 
             description(129) = 
     $ " " 
             description(130) = 
     $ " Surface Winds        2             0       NCEP GDAS" 
             description(131) = 
     $ "                                    1       DAO" 
             description(132) = 
     $ "                                    2       Other" 
             description(133) = 
     $ "                                    3       Not used" 
             description(134) = 
     $ " " 
             description(135) = 
     $ " Ecosystem Map        2             0       Loveland NA 1km" 
             description(136) = 
     $ "                                    1       Olson Ecosystem" 
             description(137) = 
     $ "                                    2       MOD12" 
             description(138) = 
     $ "                                    3       Other" 
             description(139) = 
     $ " " 
             description(140) = 
     $ " Snow mask            2             0       MOD33" 
             description(141) = 
     $ "                                    1       SSMI Product" 
             description(142) = 
     $ "                                    2       Other" 
             description(143) = 
     $ "                                    3       Not used" 
             description(144) = 
     $ " " 
             description(145) = 
     $ " Ice cover            2             0       MOD42" 
             description(146) = 
     $ "                                    1       SSMI product" 
             description(147) = 
     $ "                                    2       Other" 
             description(148) = 
     $ "                                    3       Not used" 
             description(149) = 
     $ " " 
             description(150) = 
     $ " Land/Sea Mask        2             0       USGS 1 km 6 level" 
             description(151) = 
     $ "                                    1       USGS 1 km binary" 
             description(152) = 
     $ "                                    2       Other" 
             description(153) = 
     $ "                                    3       Not used" 
             description(154) = 
     $ " " 
             description(155) = 
     $ " Digital              1             0       EOS DEM" 
             description(156) = 
     $ "   Elevation                        1       Not used" 
             description(157) = 
     $ "   Model" 
             description(158) = 
     $ " " 
             description(159) = 
     $ " Precipitable         2             0       NCEP GDAS" 
             description(160) = 
     $ "   Water                            1       DAO" 
             description(161) = 
     $ "                                    2       MOD07" 
             description(162) = 
     $ "                                    3       Other" 
             description(163) = 
     $ " " 
             description(164) = 
     $ " Spare                5" 
             description(165) = 
     $ " " 
             description(166) = 
     $ "  -------- ( 3 bytes total ) --------------------------------" 
             description(167) = 
     $ " " 
             DescCount = 167 
          End If
       End If

       if (ProgramName .EQ. "MOD_PRCSRD") then
          
          Satellite_Name = "TERRA"
          Instrument_Name = "MODIS"
          TitleCount = 1
          title = "MODIS Daily Clear Sky Grids"
          Grid_Type = "Global Equal Area"
          Grid_Resolution = "25 km"
          Start_of_Compositing_Period = "unlimited"
          End_of_Compositing_Period = "unlimited"
          Files_Used_In_Compositing = unlimited
          File_Creation_Date = "unlimited"
          HistoryCount = 1
          history = "$Id: get_spec_info.f,v 1.1 2006/02/07 22:47:44 gumley Exp $"
          
          if (InputName .EQ. "Band_Number") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Band_Number"
             long_name = 
     $ "MODIS Band Number" 
             units_str = "none" 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_01") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_02") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_03") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_04") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_05") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_06") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_07") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_17") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_18") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_19") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_26") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_20") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_21") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_22") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_23") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_24") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_25") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_27") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_28") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_29") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_30") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_31") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_32") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_33") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_34") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_35") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day_Band_36") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_26") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_20") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_21") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_22") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_23") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_24") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_25") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_27") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_28") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_29") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_30") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_31") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_32") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_33") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_34") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_35") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night_Band_36") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Land_Water_Composite_Day") then
             NumberType = DFNT_INT32
             DimList = 
     $ "LW_Statistics,Grid_size"
             long_name = 
     $ "Land/Water Statistics for daily grid boxes. 1 - Total Observations, " //
     $ " 2 - Number of Land pixels 3 - Number of Water pixels"
             units_str = "None" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 50000.0 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Land_Water_Composite_Night") then
             NumberType = DFNT_INT32
             DimList = 
     $ "LW_Statistics,Grid_size"
             long_name = 
     $ "Land/Water Statistics for nightly grid boxes. 1 - Total Observations, " //
     $ " 2 - Number of Land pixels 3 - Number of Water pixels"
             units_str = "None" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 50000.0 
             Fill_Value = 0.0 
          End If
       End If

       if (ProgramName .EQ. "MOD_PRCSR8") then
          
          Satellite_Name = "TERRA"
          Instrument_Name = "MODIS"
          TitleCount = 1
          title = "MODIS Eight Day Clear Sky Grids"
          Grid_Type = "Global Equal Area"
          Grid_Resolution = "25 km"
          Start_of_Compositing_Period = "unlimited"
          End_of_Compositing_Period = "unlimited"
          Files_Used_In_Compositing = unlimited
          File_Creation_Date = "unlimited"
          HistoryCount = 1
          history = "$Id: get_spec_info.f,v 1.1 2006/02/07 22:47:44 gumley Exp $"
          
          if (InputName .EQ. "Band_Number") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Band_Number"
             long_name = 
     $ "MODIS Band Number" 
             units_str = "none" 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_01") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_02") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_03") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_04") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_05") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_06") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_07") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_17") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_18") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_19") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_26") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_20") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_21") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_22") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_23") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_24") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_25") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_27") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_28") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_29") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_30") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_31") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_32") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_33") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_34") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_35") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Clear_Radiance_Band_36") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_26") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_20") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_21") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_22") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_23") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_24") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_25") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_27") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_28") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_29") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_30") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_31") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_32") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_33") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_34") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_35") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Clear_Radiance_Band_36") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Bands 1-7, 17-19, 26 Reflectance, Bands 20-25, 27-36 Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Day_Land_Water_Composite") then
             NumberType = DFNT_INT32
             DimList = 
     $ "LW_Statistics,Grid_size"
             long_name = 
     $ "Statistics for daily grid boxes. 1 - Total Observations, 2 - " //
     $ " Number of Land pixels 3 - Number of Water pixels"
             units_str = "None" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 50000.0 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Eight_Night_Land_Water_Composite") then
             NumberType = DFNT_INT32
             DimList = 
     $ "LW_Statistics,Grid_size"
             long_name = 
     $ "Statistics for nightly grid boxes. 1 - Total Observations, 2 " //
     $ " - Number of Land pixels 3 - Number of Water pixels"
             units_str = "None" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 50000.0 
             Fill_Value = 0.0 
          End If
       End If

       if (ProgramName .EQ. "MOD_PRCSRB") then
          
          Satellite_Name = "TERRA"
          Instrument_Name = "MODIS"
          TitleCount = 1
          title = "MODIS Daily Clear Sky Radiance Latitude Biases"
          Bands = "31, 33, 34, 35, 36"
          Lat_Resolution = "1 degree latitude"
          File_Creation_Date = "unlimited"
          HistoryCount = 1
          history = "$Id: get_spec_info.f,v 1.1 2006/02/07 22:47:44 gumley Exp $"
          
          if (InputName .EQ. "Band_Number") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Band_Number"
             long_name = 
     $ "MODIS Band Number" 
             units_str = "none" 
          End If

          if (InputName .EQ. "Ocean_Clear_Sky_Bias") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Latitude_bin,Band_Number"
             long_name = 
     $ "Ocean Latitudinally averaged eight day observed-calculated clear sky radiances" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = -50.0 
             valid_range(2) = 50.0 
             Fill_Value = -999.99 
          End If

          if (InputName .EQ. "Land_Day_Clear_Sky_Bias") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Latitude_bin,Band_Number"
             long_name = 
     $ "Land Day Latitudinally averaged eight day observed-calculated clear sky radiances" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = -50.0 
             valid_range(2) = 50.0 
             Fill_Value = -999.99 
          End If

          if (InputName .EQ. "Land_Night_Clear_Sky_Bias") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Latitude_bin,Band_Number"
             long_name = 
     $ "Land Night Latitudinal averaged eight day observed-calculated clear sky radiances" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = -50.0 
             valid_range(2) = 50.0 
             Fill_Value = -999.99 
          End If

          if (InputName .EQ. "Ocean_Day_Summations") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Summation_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Ocean Day eight day clear sky radiance summations" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Ocean_Night_Summations") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Summation_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Ocean Night eight day clear sky radiance summations" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Land_Day_Summations") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Summation_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Land Day eight day clear sky radiance summations" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Land_Night_Summations") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Summation_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Land Night eight day clear sky radiance summations" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = 0.0 
          End If

          if (InputName .EQ. "Ocean_Day_Diagnostics") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Diagnostic_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Ocean Day eight day clear sky radiance diagnostics (clear sum/total, square root of bias)" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = -999.99 
          End If

          if (InputName .EQ. "Ocean_Night_Diagnostics") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Diagnostic_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Ocean Night eight day clear sky radiance diagnostics (clear sum/total, " //
     $ " square root of bias)"
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = -999.99 
          End If

          if (InputName .EQ. "Land_Day_Diagnostics") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Diagnostic_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Land Day eight day clear sky radiance diagnostics (clear sum/total, square root of bias)" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = -999.99 
          End If

          if (InputName .EQ. "Land_Night_Diagnostics") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Diagnostic_stats,Latitude_bin,Band_Number"
             long_name = 
     $ "Land Night eight day clear sky radiance diagnostics (clear sum/total, square root of bias)" 
             units_str = "Watts/meter2/steradian/micron" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = -999.99 
          End If
       End If

       if (ProgramName .EQ. "MOD35_CLRRAD") then
          
          Granule_Start_TAI = unlimited
          Granule_End_TAI = unlimited
          TitleCount = 1
          title = "MODIS Level 2 Cloud Mask Clear Radiances"
          HistoryCount = 1
          history = "$Id: get_spec_info.f,v 1.1 2006/02/07 22:47:44 gumley Exp $"
          
          if (InputName .EQ. "Band_Number") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Band_Number"
             long_name = 
     $ "MODIS Band Number" 
             units_str = "none" 
          End If

          if (InputName .EQ. "Grid_Index_Day") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Size_of_One,Number_Cells_Day"
             long_name = 
     $ "Index of daytime granule grid boxes of clear sky to global radiance grid map" 
             units_str = "none" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 1.0 
             valid_range(2) = 814880.0 
             Fill_Value = -999.0 
          End If

          if (InputName .EQ. "Grid_Index_Night") then
             NumberType = DFNT_INT32
             DimList = 
     $ "Size_of_One,Number_Cells_Night"
             long_name = 
     $ "Index of nighttime granule grid boxes of clear sky to global radiance grid map" 
             units_str = "none" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 1.0 
             valid_range(2) = 814880.0 
             Fill_Value = -999.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Day") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Band_Number,Number_Cells_Day"
             long_name = 
     $ "Statistics for daily global grid boxes" 
             units_str = "Statistic Dependent" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = -999.0 
          End If

          if (InputName .EQ. "Clear_Radiance_Night") then
             NumberType = DFNT_FLOAT32
             DimList = 
     $ "Statistics,Band_Number,Number_Cells_Night"
             long_name = 
     $ "Statistics for nightly global grid boxes" 
             units_str = "Statistic Dependent" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 3.40e38 
             Fill_Value = -999.0 
          End If

          if (InputName .EQ. "Land_Water_Day") then
             NumberType = DFNT_INT32
             DimList = 
     $ "LW_Statistics,Number_Cells_Day"
             long_name = 
     $ "Number of Land/Water observations per daytime grid box" 
             units_str = "None" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 50000.0 
             Fill_Value = -999.0 
          End If

          if (InputName .EQ. "Land_Water_Night") then
             NumberType = DFNT_INT32
             DimList = 
     $ "LW_Statistics,Number_Cells_Night"
             long_name = 
     $ "Number of Land/Water observations per nighttime grid box" 
             units_str = "None" 
             scale_factor = 1.0 
             add_offset = 0.0 
             Param_Type = "MODIS Output" 
             Geolocation_Pointer = "None" 
             valid_range(1) = 0.0 
             valid_range(2) = 50000.0 
             Fill_Value = -999.0 
          End If
       End If

       return
       end



       SUBROUTINE GET_SPEC_DATA(PROGRAMNAME, FIELDNAMES, DIMNAMES,
     $        DIMNUMBERS, DIMCOUNT, DATANAMES, DATACOUNT,
     $        DATAVALUES, NUMOFDATA, LIMIT, FIELDCOUNT)

       implicit none
       save

c---------------------------------------------------------------------
C!F77
c
c!DESCRIPTION:
c  Subroutine which extracts the correct file spec information
c  for the given product (MOD35, MOD07, or MOD06)
c
c!INPUT PARAMETERS:
c ProgramName   Ouput hdf file name
c Limit         Maximum size of Arrays
c
c!OUTPUT PARAMETERS:
c FieldNames    HDF Field Names for SDS
c FieldCount    Number of Dimension Values
c DimNames      Dimension Names for SDS
c DimNumbers    Dimension Values
c DimCount      Number of Dimension Values
c DataNames     Data Names for SDS
c DataNumbers   Data Values
c NumOfData     Number of Data Values
c
c!REVISION HISTORY:
c   This FORTRAN source file is created by spec2fort.c
c   spec2fort.c was designed by Walter.Wolf@ssec.wisc.edu
c
c!TEAM-UNIQUE HEADER:
c
c!REFERENCES AND CREDITS:
c
c!END
c---------------------------------------------------------------------

       character*(*) ProgramName
       character*(*) FieldNames(*), DimNames(*), DataNames(*)
       integer Limit, FieldCount, NumOfData
       integer DimNumbers(*), DataCount(*), DimCount

       real DataValues(Limit, Limit)
       integer unlimited

       NumOfData = 0
       DimCount = 0
       FieldCount = 0

       unlimited = 0

       if (ProgramName .EQ. "MOD06") then
          DimNames(1) = "Cell_Across_Swath_5km"
          DimNumbers(1) = 270
          DimNames(2) = "Cell_Along_Swath_5km"
          DimNumbers(2) = 406
          DimNames(3) = "Cell_Across_Swath_1km"
          DimNumbers(3) = 1354
          DimNames(4) = "Cell_Along_Swath_1km"
          DimNumbers(4) = 2030
          DimNames(5) = "Band_Number"
          DimNumbers(5) = 7
          DimNames(6) = "Band_Ratio"
          DimNumbers(6) = 5
          DimNames(7) = "Band_Forcing"
          DimNumbers(7) = 5
          DimNames(8) = "Band_Difference"
          DimNumbers(8) = 2
          DimNames(9) = "Radius_Difference"
          DimNumbers(9) = 2
          DimNames(10) = "QA_Parameter_5km"
          DimNumbers(10) = 10
          DimNames(11) = "QA_Parameter_1km"
          DimNumbers(11) = 5
          DimNames(12) = "Cloud_Mask_1km_Num_Bytes"
          DimNumbers(12) = 2
          DimNames(13) = "Statistic_Parameter_1km"
          DimNumbers(13) = 20
          DimCount = 13 
          DataNames(1) = "Band_Number" 
          DataValues(1,1) = 29
          DataValues(1,2) = 31
          DataValues(1,3) = 32
          DataValues(1,4) = 33
          DataValues(1,5) = 34
          DataValues(1,6) = 35
          DataValues(1,7) = 36
          DataCount(1) = 7
          NumOfData = 1 
          FieldNames(1) = "Band_Number"
          FieldNames(2) = "Statistics_1km"
          FieldNames(3) = "Scan_Start_Time"
          FieldNames(4) = "Latitude"
          FieldNames(5) = "Longitude"
          FieldNames(6) = "Solar_Zenith"
          FieldNames(7) = "Solar_Azimuth"
          FieldNames(8) = "Sensor_Zenith"
          FieldNames(9) = "Sensor_Azimuth"
          FieldNames(10) = "Brightness_Temperature"
          FieldNames(11) = "Surface_Temperature"
          FieldNames(12) = "Surface_Pressure"
          FieldNames(13) = "Processing_Flag"
          FieldNames(14) = "Cloud_Height_Method"
          FieldNames(15) = "Cloud_Top_Pressure"
          FieldNames(16) = "Cloud_Top_Pressure_Night"
          FieldNames(17) = "Cloud_Top_Pressure_Day"
          FieldNames(18) = "Cloud_Top_Temperature"
          FieldNames(19) = "Cloud_Top_Temperature_Night"
          FieldNames(20) = "Cloud_Top_Temperature_Day"
          FieldNames(21) = "Tropopause_Height"
          FieldNames(22) = "Cloud_Fraction"
          FieldNames(23) = "Cloud_Fraction_Night"
          FieldNames(24) = "Cloud_Fraction_Day"
          FieldNames(25) = "Cloud_Effective_Emissivity"
          FieldNames(26) = "Cloud_Effective_Emissivity_Night"
          FieldNames(27) = "Cloud_Effective_Emissivity_Day"
          FieldNames(28) = "Cloud_Top_Pressure_Infrared"
          FieldNames(29) = "Spectral_Cloud_Forcing"
          FieldNames(30) = "Cloud_Top_Pressure_From_Ratios"
          FieldNames(31) = "Surface_Type"
          FieldNames(32) = "Radiance_Variance"
          FieldNames(33) = "Brightness_Temperature_Difference"
          FieldNames(34) = "Cloud_Phase_Infrared"
          FieldNames(35) = "Cloud_Phase_Infrared_Night"
          FieldNames(36) = "Cloud_Phase_Infrared_Day"
          FieldNames(37) = "Cloud_Effective_Radius"
          FieldNames(38) = "Cloud_Optical_Thickness"
          FieldNames(39) = "Cloud_Effective_Radius_1621"
          FieldNames(40) = "Cloud_Optical_Thickness_1621"
          FieldNames(41) = "Effective_Radius_Difference"
          FieldNames(42) = "Cloud_Water_Path"
          FieldNames(43) = "Cloud_Water_Path_1621"
          FieldNames(44) = "Cloud_Effective_Radius_Uncertainty"
          FieldNames(45) = "Cloud_Optical_Thickness_Uncertainty"
          FieldNames(46) = "Cloud_Water_Path_Uncertainty"
          FieldNames(47) = "Cloud_Effective_Radius_Uncertainty_1621"
          FieldNames(48) = "Cloud_Optical_Thickness_Uncertainty_1621"
          FieldNames(49) = "Cloud_Water_Path_Uncertainty_1621"
          FieldNames(50) = "Cloud_Phase_Optical_Properties"
          FieldNames(51) = "Cloud_Multi_Layer_Flag"
          FieldNames(52) = "Cirrus_Reflectance"
          FieldNames(53) = "Cirrus_Reflectance_Flag"
          FieldNames(54) = "Cloud_Mask_5km"
          FieldNames(55) = "Quality_Assurance_5km"
          FieldNames(56) = "Cloud_Mask_1km"
          FieldNames(57) = "Quality_Assurance_1km"

          FieldCount = 57

       End If

       if (ProgramName .EQ. "MOD07") then
          DimNames(1) = "Cell_Across_Swath"
          DimNumbers(1) = 270
          DimNames(2) = "Cell_Along_Swath"
          DimNumbers(2) = 406
          DimNames(3) = "Band_Number"
          DimNumbers(3) = 12
          DimNames(4) = "Pressure_Level"
          DimNumbers(4) = 20
          DimNames(5) = "Output_Parameter"
          DimNumbers(5) = 10
          DimNames(6) = "Water_Vapor_QA_Bytes"
          DimNumbers(6) = 5
          DimCount = 6 
          DataNames(1) = "Band_Number" 
          DataValues(1,1) = 24
          DataValues(1,2) = 25
          DataValues(1,3) = 27
          DataValues(1,4) = 28
          DataValues(1,5) = 29
          DataValues(1,6) = 30
          DataValues(1,7) = 31
          DataValues(1,8) = 32
          DataValues(1,9) = 33
          DataValues(1,10) = 34
          DataValues(1,11) = 35
          DataValues(1,12) = 36
          DataCount(1) = 12
          DataNames(2) = "Pressure_Level" 
          DataValues(2,1) = 05.
          DataValues(2,2) = 10.
          DataValues(2,3) = 20.
          DataValues(2,4) = 30.
          DataValues(2,5) = 50.
          DataValues(2,6) = 70.
          DataValues(2,7) = 100.
          DataValues(2,8) = 150.
          DataValues(2,9) = 200.
          DataValues(2,10) = 250.
          DataValues(2,11) = 300.
          DataValues(2,12) = 400.
          DataValues(2,13) = 500.
          DataValues(2,14) = 620.
          DataValues(2,15) = 700.
          DataValues(2,16) = 780.
          DataValues(2,17) = 850.
          DataValues(2,18) = 920.
          DataValues(2,19) = 950.
          DataValues(2,20) = 1000.
          DataCount(2) = 20
          NumOfData = 2 
          FieldNames(1) = "Band_Number"
          FieldNames(2) = "Pressure_Level"
          FieldNames(3) = "Scan_Start_Time"
          FieldNames(4) = "Latitude"
          FieldNames(5) = "Longitude"
          FieldNames(6) = "Solar_Zenith"
          FieldNames(7) = "Solar_Azimuth"
          FieldNames(8) = "Sensor_Zenith"
          FieldNames(9) = "Sensor_Azimuth"
          FieldNames(10) = "Brightness_Temperature"
          FieldNames(11) = "Cloud_Mask"
          FieldNames(12) = "Surface_Temperature"
          FieldNames(13) = "Surface_Pressure"
          FieldNames(14) = "Surface_Elevation"
          FieldNames(15) = "Processing_Flag"
          FieldNames(16) = "Tropopause_Height"
          FieldNames(17) = "Guess_Temperature_Profile"
          FieldNames(18) = "Guess_Moisture_Profile"
          FieldNames(19) = "Retrieved_Temperature_Profile"
          FieldNames(20) = "Retrieved_Moisture_Profile"
          FieldNames(21) = "Retrieved_Height_Profile"
          FieldNames(22) = "Total_Ozone"
          FieldNames(23) = "Total_Totals"
          FieldNames(24) = "Lifted_Index"
          FieldNames(25) = "K_Index"
          FieldNames(26) = "Water_Vapor"
          FieldNames(27) = "Water_Vapor_Direct"
          FieldNames(28) = "Water_Vapor_Low"
          FieldNames(29) = "Water_Vapor_High"
          FieldNames(30) = "Quality_Assurance"
          FieldNames(31) = "Quality_Assurance_Infrared"

          FieldCount = 31

       End If

       if (ProgramName .EQ. "MOD35") then
          DimNames(1) = "Cell_Across_Swath_1km"
          DimNumbers(1) = 1354
          DimNames(2) = "Cell_Across_Swath_5km"
          DimNumbers(2) = 270
          DimNames(3) = "Cell_Along_Swath_1km"
          DimNumbers(3) = 2030
          DimNames(4) = "Cell_Along_Swath_5km"
          DimNumbers(4) = 406
          DimNames(5) = "Byte_Segment"
          DimNumbers(5) = 6
          DimNames(6) = "QA_Dimension"
          DimNumbers(6) = 10
          DimCount = 6 
          DataNames(1) = "Byte_Segment" 
          DataValues(1,1) = 1
          DataValues(1,2) = 2
          DataValues(1,3) = 3
          DataValues(1,4) = 4
          DataValues(1,5) = 5
          DataValues(1,6) = 6
          DataCount(1) = 6
          NumOfData = 1 
          FieldNames(1) = "Byte_Segment"
          FieldNames(2) = "Scan_Start_Time"
          FieldNames(3) = "Latitude"
          FieldNames(4) = "Longitude"
          FieldNames(5) = "Solar_Zenith"
          FieldNames(6) = "Solar_Azimuth"
          FieldNames(7) = "Sensor_Zenith"
          FieldNames(8) = "Sensor_Azimuth"
          FieldNames(9) = "Cloud_Mask"
          FieldNames(10) = "Quality_Assurance"

          FieldCount = 10

       End If

       if (ProgramName .EQ. "MOD_PRCSRD") then
          DimNames(1) = "Grid_size"
          DimNumbers(1) = 814880
          DimNames(2) = "Band_Number"
          DimNumbers(2) = 27
          DimNames(3) = "Statistics"
          DimNumbers(3) = 9
          DimNames(4) = "LW_Statistics"
          DimNumbers(4) = 3
          DimCount = 4 
          DataNames(1) = "Band_Number" 
          DataValues(1,1) = 1
          DataValues(1,2) = 2
          DataValues(1,3) = 3
          DataValues(1,4) = 4
          DataValues(1,5) = 5
          DataValues(1,6) = 6
          DataValues(1,7) = 7
          DataValues(1,8) = 17
          DataValues(1,9) = 18
          DataValues(1,10) = 19
          DataValues(1,11) = 26
          DataValues(1,12) = 20
          DataValues(1,13) = 21
          DataValues(1,14) = 22
          DataValues(1,15) = 23
          DataValues(1,16) = 24
          DataValues(1,17) = 25
          DataValues(1,18) = 27
          DataValues(1,19) = 28
          DataValues(1,20) = 29
          DataValues(1,21) = 30
          DataValues(1,22) = 31
          DataValues(1,23) = 32
          DataValues(1,24) = 33
          DataValues(1,25) = 34
          DataValues(1,26) = 35
          DataValues(1,27) = 36
          DataCount(1) = 27
          NumOfData = 1 
          FieldNames(1) = "Band_Number"
          FieldNames(2) = "Clear_Radiance_Day_Band_01"
          FieldNames(3) = "Clear_Radiance_Day_Band_02"
          FieldNames(4) = "Clear_Radiance_Day_Band_03"
          FieldNames(5) = "Clear_Radiance_Day_Band_04"
          FieldNames(6) = "Clear_Radiance_Day_Band_05"
          FieldNames(7) = "Clear_Radiance_Day_Band_06"
          FieldNames(8) = "Clear_Radiance_Day_Band_07"
          FieldNames(9) = "Clear_Radiance_Day_Band_17"
          FieldNames(10) = "Clear_Radiance_Day_Band_18"
          FieldNames(11) = "Clear_Radiance_Day_Band_19"
          FieldNames(12) = "Clear_Radiance_Day_Band_26"
          FieldNames(13) = "Clear_Radiance_Day_Band_20"
          FieldNames(14) = "Clear_Radiance_Day_Band_21"
          FieldNames(15) = "Clear_Radiance_Day_Band_22"
          FieldNames(16) = "Clear_Radiance_Day_Band_23"
          FieldNames(17) = "Clear_Radiance_Day_Band_24"
          FieldNames(18) = "Clear_Radiance_Day_Band_25"
          FieldNames(19) = "Clear_Radiance_Day_Band_27"
          FieldNames(20) = "Clear_Radiance_Day_Band_28"
          FieldNames(21) = "Clear_Radiance_Day_Band_29"
          FieldNames(22) = "Clear_Radiance_Day_Band_30"
          FieldNames(23) = "Clear_Radiance_Day_Band_31"
          FieldNames(24) = "Clear_Radiance_Day_Band_32"
          FieldNames(25) = "Clear_Radiance_Day_Band_33"
          FieldNames(26) = "Clear_Radiance_Day_Band_34"
          FieldNames(27) = "Clear_Radiance_Day_Band_35"
          FieldNames(28) = "Clear_Radiance_Day_Band_36"
          FieldNames(29) = "Clear_Radiance_Night_Band_26"
          FieldNames(30) = "Clear_Radiance_Night_Band_20"
          FieldNames(31) = "Clear_Radiance_Night_Band_21"
          FieldNames(32) = "Clear_Radiance_Night_Band_22"
          FieldNames(33) = "Clear_Radiance_Night_Band_23"
          FieldNames(34) = "Clear_Radiance_Night_Band_24"
          FieldNames(35) = "Clear_Radiance_Night_Band_25"
          FieldNames(36) = "Clear_Radiance_Night_Band_27"
          FieldNames(37) = "Clear_Radiance_Night_Band_28"
          FieldNames(38) = "Clear_Radiance_Night_Band_29"
          FieldNames(39) = "Clear_Radiance_Night_Band_30"
          FieldNames(40) = "Clear_Radiance_Night_Band_31"
          FieldNames(41) = "Clear_Radiance_Night_Band_32"
          FieldNames(42) = "Clear_Radiance_Night_Band_33"
          FieldNames(43) = "Clear_Radiance_Night_Band_34"
          FieldNames(44) = "Clear_Radiance_Night_Band_35"
          FieldNames(45) = "Clear_Radiance_Night_Band_36"
          FieldNames(46) = "Land_Water_Composite_Day"
          FieldNames(47) = "Land_Water_Composite_Night"

          FieldCount = 47

       End If

       if (ProgramName .EQ. "MOD_PRCSR8") then
          DimNames(1) = "Grid_size"
          DimNumbers(1) = 814880
          DimNames(2) = "Band_Number"
          DimNumbers(2) = 27
          DimNames(3) = "Statistics"
          DimNumbers(3) = 9
          DimNames(4) = "LW_Statistics"
          DimNumbers(4) = 3
          DimCount = 4 
          DataNames(1) = "Band_Number" 
          DataValues(1,1) = 1
          DataValues(1,2) = 2
          DataValues(1,3) = 3
          DataValues(1,4) = 4
          DataValues(1,5) = 5
          DataValues(1,6) = 6
          DataValues(1,7) = 7
          DataValues(1,8) = 17
          DataValues(1,9) = 18
          DataValues(1,10) = 19
          DataValues(1,11) = 26
          DataValues(1,12) = 20
          DataValues(1,13) = 21
          DataValues(1,14) = 22
          DataValues(1,15) = 23
          DataValues(1,16) = 24
          DataValues(1,17) = 25
          DataValues(1,18) = 27
          DataValues(1,19) = 28
          DataValues(1,20) = 29
          DataValues(1,21) = 30
          DataValues(1,22) = 31
          DataValues(1,23) = 32
          DataValues(1,24) = 33
          DataValues(1,25) = 34
          DataValues(1,26) = 35
          DataValues(1,27) = 36
          DataCount(1) = 27
          NumOfData = 1 
          FieldNames(1) = "Band_Number"
          FieldNames(2) = "Eight_Day_Clear_Radiance_Band_01"
          FieldNames(3) = "Eight_Day_Clear_Radiance_Band_02"
          FieldNames(4) = "Eight_Day_Clear_Radiance_Band_03"
          FieldNames(5) = "Eight_Day_Clear_Radiance_Band_04"
          FieldNames(6) = "Eight_Day_Clear_Radiance_Band_05"
          FieldNames(7) = "Eight_Day_Clear_Radiance_Band_06"
          FieldNames(8) = "Eight_Day_Clear_Radiance_Band_07"
          FieldNames(9) = "Eight_Day_Clear_Radiance_Band_17"
          FieldNames(10) = "Eight_Day_Clear_Radiance_Band_18"
          FieldNames(11) = "Eight_Day_Clear_Radiance_Band_19"
          FieldNames(12) = "Eight_Day_Clear_Radiance_Band_26"
          FieldNames(13) = "Eight_Day_Clear_Radiance_Band_20"
          FieldNames(14) = "Eight_Day_Clear_Radiance_Band_21"
          FieldNames(15) = "Eight_Day_Clear_Radiance_Band_22"
          FieldNames(16) = "Eight_Day_Clear_Radiance_Band_23"
          FieldNames(17) = "Eight_Day_Clear_Radiance_Band_24"
          FieldNames(18) = "Eight_Day_Clear_Radiance_Band_25"
          FieldNames(19) = "Eight_Day_Clear_Radiance_Band_27"
          FieldNames(20) = "Eight_Day_Clear_Radiance_Band_28"
          FieldNames(21) = "Eight_Day_Clear_Radiance_Band_29"
          FieldNames(22) = "Eight_Day_Clear_Radiance_Band_30"
          FieldNames(23) = "Eight_Day_Clear_Radiance_Band_31"
          FieldNames(24) = "Eight_Day_Clear_Radiance_Band_32"
          FieldNames(25) = "Eight_Day_Clear_Radiance_Band_33"
          FieldNames(26) = "Eight_Day_Clear_Radiance_Band_34"
          FieldNames(27) = "Eight_Day_Clear_Radiance_Band_35"
          FieldNames(28) = "Eight_Day_Clear_Radiance_Band_36"
          FieldNames(29) = "Eight_Night_Clear_Radiance_Band_26"
          FieldNames(30) = "Eight_Night_Clear_Radiance_Band_20"
          FieldNames(31) = "Eight_Night_Clear_Radiance_Band_21"
          FieldNames(32) = "Eight_Night_Clear_Radiance_Band_22"
          FieldNames(33) = "Eight_Night_Clear_Radiance_Band_23"
          FieldNames(34) = "Eight_Night_Clear_Radiance_Band_24"
          FieldNames(35) = "Eight_Night_Clear_Radiance_Band_25"
          FieldNames(36) = "Eight_Night_Clear_Radiance_Band_27"
          FieldNames(37) = "Eight_Night_Clear_Radiance_Band_28"
          FieldNames(38) = "Eight_Night_Clear_Radiance_Band_29"
          FieldNames(39) = "Eight_Night_Clear_Radiance_Band_30"
          FieldNames(40) = "Eight_Night_Clear_Radiance_Band_31"
          FieldNames(41) = "Eight_Night_Clear_Radiance_Band_32"
          FieldNames(42) = "Eight_Night_Clear_Radiance_Band_33"
          FieldNames(43) = "Eight_Night_Clear_Radiance_Band_34"
          FieldNames(44) = "Eight_Night_Clear_Radiance_Band_35"
          FieldNames(45) = "Eight_Night_Clear_Radiance_Band_36"
          FieldNames(46) = "Eight_Day_Land_Water_Composite"
          FieldNames(47) = "Eight_Night_Land_Water_Composite"

          FieldCount = 47

       End If

       if (ProgramName .EQ. "MOD_PRCSRB") then
          DimNames(1) = "Latitude_bin"
          DimNumbers(1) = 181
          DimNames(2) = "Band_Number"
          DimNumbers(2) = 5
          DimNames(3) = "Summation_stats"
          DimNumbers(3) = 4
          DimNames(4) = "Diagnostic_stats"
          DimNumbers(4) = 2
          DimCount = 4 
          DataNames(1) = "Band_Number" 
          DataValues(1,1) = 31
          DataValues(1,2) = 33
          DataValues(1,3) = 34
          DataValues(1,4) = 35
          DataValues(1,5) = 36
          DataCount(1) = 5
          NumOfData = 1 
          FieldNames(1) = "Band_Number"
          FieldNames(2) = "Ocean_Clear_Sky_Bias"
          FieldNames(3) = "Land_Day_Clear_Sky_Bias"
          FieldNames(4) = "Land_Night_Clear_Sky_Bias"
          FieldNames(5) = "Ocean_Day_Summations"
          FieldNames(6) = "Ocean_Night_Summations"
          FieldNames(7) = "Land_Day_Summations"
          FieldNames(8) = "Land_Night_Summations"
          FieldNames(9) = "Ocean_Day_Diagnostics"
          FieldNames(10) = "Ocean_Night_Diagnostics"
          FieldNames(11) = "Land_Day_Diagnostics"
          FieldNames(12) = "Land_Night_Diagnostics"

          FieldCount = 12

       End If

       if (ProgramName .EQ. "MOD35_CLRRAD") then
          DimNames(1) = "Statistics"
          DimNumbers(1) = 9
          DimNames(2) = "LW_Statistics"
          DimNumbers(2) = 3
          DimNames(3) = "Band_Number"
          DimNumbers(3) = 27
          DimNames(4) = "Size_of_One"
          DimNumbers(4) = 1
          DimNames(5) = "Number_Cells_Day"
          DimNumbers(5) = unlimited
          DimNames(6) = "Number_Cells_Night"
          DimNumbers(6) = unlimited
          DimCount = 6 
          DataNames(1) = "Band_Number" 
          DataValues(1,1) = 1
          DataValues(1,2) = 2
          DataValues(1,3) = 3
          DataValues(1,4) = 4
          DataValues(1,5) = 5
          DataValues(1,6) = 6
          DataValues(1,7) = 7
          DataValues(1,8) = 17
          DataValues(1,9) = 18
          DataValues(1,10) = 19
          DataValues(1,11) = 26
          DataValues(1,12) = 20
          DataValues(1,13) = 21
          DataValues(1,14) = 22
          DataValues(1,15) = 23
          DataValues(1,16) = 24
          DataValues(1,17) = 25
          DataValues(1,18) = 27
          DataValues(1,19) = 28
          DataValues(1,20) = 29
          DataValues(1,21) = 30
          DataValues(1,22) = 31
          DataValues(1,23) = 32
          DataValues(1,24) = 33
          DataValues(1,25) = 34
          DataValues(1,26) = 35
          DataValues(1,27) = 36
          DataCount(1) = 27
          NumOfData = 1 
          FieldNames(1) = "Band_Number"
          FieldNames(2) = "Grid_Index_Day"
          FieldNames(3) = "Grid_Index_Night"
          FieldNames(4) = "Clear_Radiance_Day"
          FieldNames(5) = "Clear_Radiance_Night"
          FieldNames(6) = "Land_Water_Day"
          FieldNames(7) = "Land_Water_Night"

          FieldCount = 7

       End If

       return
       end
